@@ -38,6 +38,8 @@ extensions = [
 
 templates_path = ["_templates"]
 
+html_extra_path = ["googleaf254801a5285c31.html", "sitemap-index.xml"]
+
 # List of patterns, relative to source directory, that match files and
 # directories to ignore when looking for source files.
 # This pattern also affects html_static_path and html_extra_path.
@@ -100,7 +102,7 @@ html_static_path = ["_static"]
 html_css_files = [
     "css/logo.css",
     "css/github_issue_links.css",
-    "css/custom.css"
+    "css/custom.css",
 ]
 html_js_files = [
     "js/github_issue_links.js",
