@@ -15,8 +15,6 @@ class Cloud:
 
     :cloud_credentials_path:
         A string containing the path for the pycloudlib cloud credentials file
-    :machine_type:
-        A string representing the type of machine to launch (pro or generic)
     :region:
         The region to create the cloud resources on
     :param tag:
@@ -30,7 +28,6 @@ class Cloud:
 
     def __init__(
         self,
-        machine_type: str,
         cloud_credentials_path: Optional[str],
         tag: Optional[str] = None,
         timestamp_suffix: bool = True,
@@ -39,11 +36,11 @@ class Cloud:
             self.tag = tag
         else:
             self.tag = "uaclient-ci"
-        self.machine_type = machine_type
         self._api = None
         self.key_name = pycloudlib.util.get_timestamped_tag(self.tag)
         self.timestamp_suffix = timestamp_suffix
         self.cloud_credentials_path = cloud_credentials_path
+        self._ssh_key_managed = False
 
     @property
     def pycloudlib_cls(self):
@@ -65,6 +62,7 @@ class Cloud:
     def _create_instance(
         self,
         series: str,
+        machine_type: str,
         instance_name: Optional[str] = None,
         image_name: Optional[str] = None,
         user_data: Optional[str] = None,
@@ -77,6 +75,8 @@ class Cloud:
             The ubuntu release to be used when creating an instance. We will
             create an image based on this value if the used does not provide
             a image_name value
+        :machine_type:
+            string representing the type of machine to launch (pro or generic)
         :param instance_name:
             The name of the instance to be created
         :param image_name:
@@ -115,6 +115,7 @@ class Cloud:
     def launch(
         self,
         series: str,
+        machine_type: str,
         instance_name: Optional[str] = None,
         image_name: Optional[str] = None,
         user_data: Optional[str] = None,
@@ -127,6 +128,8 @@ class Cloud:
             The ubuntu release to be used when creating an instance. We will
             create an image based on this value if the used does not provide
             a image_name value
+        :machine_type:
+            string representing the type of machine to launch (pro or generic)
         :param instance_name:
             The name of the instance to be created
         :param image_name:
@@ -143,6 +146,7 @@ class Cloud:
         """
         inst = self._create_instance(
             series=series,
+            machine_type=machine_type,
             instance_name=instance_name,
             image_name=image_name,
             user_data=user_data,
@@ -168,11 +172,15 @@ class Cloud:
         """
         return instance.id
 
-    def locate_image_name(self, series: str) -> str:
+    def locate_image_name(
+        self, series: str, machine_type: str, daily: bool = True
+    ) -> str:
         """Locate and return the image name to use for vm provision.
 
         :param series:
             The ubuntu release to be used when locating the image name
+        :machine_type:
+            string representing the type of machine to launch (pro or generic)
 
         :returns:
             A image name to use when provisioning a virtual machine
@@ -184,12 +192,19 @@ class Cloud:
             )
 
         image_type = ImageType.GENERIC
-        if "pro.fips" in self.machine_type:
+        if "pro-fips" in machine_type:
             image_type = ImageType.PRO_FIPS
-        elif "pro" in self.machine_type:
+        elif "pro" in machine_type:
             image_type = ImageType.PRO
 
-        return self.api.daily_image(release=series, image_type=image_type)
+        if daily:
+            logging.debug("looking up daily image for {}".format(series))
+            return self.api.daily_image(release=series, image_type=image_type)
+        else:
+            logging.debug("looking up released image for {}".format(series))
+            return self.api.released_image(
+                release=series, image_type=image_type
+            )
 
     def manage_ssh_key(
         self,
@@ -202,6 +217,11 @@ class Cloud:
             Location of the private key path to use. If None, the location
             will be a default location.
         """
+        if self._ssh_key_managed:
+            logging.debug("SSH key already set up")
+            return
+
+        logging.debug("Setting up SSH key")
         if key_name:
             self.key_name = key_name
         cloud_name = self.name.lower().replace("_", "-")
@@ -221,10 +241,17 @@ class Cloud:
         self.api.use_key(
             public_key_path=pub_key_path, private_key_path=priv_key_path
         )
+        self._ssh_key_managed = True
 
 
 class EC2(Cloud):
-    """Class that represents the EC2 cloud provider."""
+    """
+    Class that represents the EC2 cloud provider.
+
+    For AWS, we need to specify on the pycloudlib config file that
+    the AWS region must be us-east-2. The reason for that is because
+    our image ids were captured using that region.
+    """
 
     name = "aws"
 
@@ -270,6 +297,7 @@ class EC2(Cloud):
     def _create_instance(
         self,
         series: str,
+        machine_type: str,
         instance_name: Optional[str] = None,
         image_name: Optional[str] = None,
         user_data: Optional[str] = None,
@@ -282,6 +310,8 @@ class EC2(Cloud):
             The ubuntu release to be used when creating an instance. We will
             create an image based on this value if the used does not provide
             a image_name value
+        :machine_type:
+            string representing the type of machine to launch (pro or generic)
         :param instance_name:
             The name of the instance to be created
         :param image_name:
@@ -297,7 +327,16 @@ class EC2(Cloud):
             An AWS cloud provider instance
         """
         if not image_name:
-            image_name = self.locate_image_name(series)
+            if series == "xenial" and "pro" not in machine_type:
+                logging.debug(
+                    "defaulting to non-daily image for awsgeneric-16.04"
+                )
+                daily = False
+            else:
+                daily = True
+            image_name = self.locate_image_name(
+                series, machine_type, daily=daily
+            )
 
         logging.info(
             "--- Launching AWS image {}({})".format(image_name, series)
@@ -316,7 +355,7 @@ class EC2(Cloud):
 class Azure(Cloud):
     """Class that represents the Azure cloud provider."""
 
-    name = "Azure"
+    name = "azure"
 
     @property
     def pycloudlib_cls(self):
@@ -376,6 +415,7 @@ class Azure(Cloud):
     def _create_instance(
         self,
         series: str,
+        machine_type: str,
         instance_name: Optional[str] = None,
         image_name: Optional[str] = None,
         user_data: Optional[str] = None,
@@ -388,6 +428,8 @@ class Azure(Cloud):
             The ubuntu release to be used when creating an instance. We will
             create an image based on this value if the used does not provide
             a image_name value
+        :machine_type:
+            string representing the type of machine to launch (pro or generic)
         :param instance_name:
             The name of the instance to be created
         :param image_name:
@@ -403,7 +445,7 @@ class Azure(Cloud):
             An Azure cloud provider instance
         """
         if not image_name:
-            image_name = self.locate_image_name(series)
+            image_name = self.locate_image_name(series, machine_type)
 
         logging.info(
             "--- Launching Azure image {}({})".format(image_name, series)
@@ -430,13 +472,11 @@ class GCP(Cloud):
 
     def __init__(
         self,
-        machine_type: str,
         cloud_credentials_path: Optional[str],
         tag: Optional[str] = None,
         timestamp_suffix: bool = True,
     ) -> None:
         super().__init__(
-            machine_type=machine_type,
             cloud_credentials_path=cloud_credentials_path,
             tag=tag,
             timestamp_suffix=timestamp_suffix,
@@ -494,6 +534,7 @@ class GCP(Cloud):
     def _create_instance(
         self,
         series: str,
+        machine_type: str,
         instance_name: Optional[str] = None,
         image_name: Optional[str] = None,
         user_data: Optional[str] = None,
@@ -506,6 +547,8 @@ class GCP(Cloud):
             The ubuntu release to be used when creating an instance. We will
             create an image based on this value if the used does not provide
             a image_name value
+        :machine_type:
+            string representing the type of machine to launch (pro or generic)
         :param instance_name:
             The name of the instance to be created
         :param image_name:
@@ -521,7 +564,7 @@ class GCP(Cloud):
             An GCP cloud provider instance
         """
         if not image_name:
-            image_name = self.locate_image_name(series)
+            image_name = self.locate_image_name(series, machine_type)
 
         logging.info(
             "--- Launching GCP image {}({})".format(image_name, series)
@@ -536,6 +579,7 @@ class _LXD(Cloud):
     def _create_instance(
         self,
         series: str,
+        machine_type: str,
         instance_name: Optional[str] = None,
         image_name: Optional[str] = None,
         user_data: Optional[str] = None,
@@ -548,6 +592,8 @@ class _LXD(Cloud):
             The ubuntu release to be used when creating an instance. We will
             create an image based on this value if the used does not provide
             a image_name value
+        :machine_type:
+            string representing the type of machine to launch (pro or generic)
         :param instance_name:
             The name of the instance to be created
         :param image_name:
@@ -563,7 +609,7 @@ class _LXD(Cloud):
             An AWS cloud provider instance
         """
         if not image_name:
-            image_name = self.locate_image_name(series)
+            image_name = self.locate_image_name(series, machine_type)
 
         image_type = self.name.title().replace("-", " ")
 
@@ -603,11 +649,15 @@ class _LXD(Cloud):
         # instead of the instance id
         return instance.name
 
-    def locate_image_name(self, series: str) -> str:
+    def locate_image_name(
+        self, series: str, machine_type: str, daily: bool = True
+    ) -> str:
         """Locate and return the image name to use for vm provision.
 
         :param series:
             The ubuntu release to be used when locating the image name
+        :machine_type:
+            string representing the type of machine to launch (pro or generic)
 
         :returns:
             A image name to use when provisioning a virtual machine
@@ -618,7 +668,13 @@ class _LXD(Cloud):
                 "Must provide either series or image_name to launch azure"
             )
 
-        image_name = self.api.daily_image(release=series)
+        if daily:
+            logging.debug("looking up daily image for {}".format(series))
+            image_name = self.api.daily_image(release=series)
+        else:
+            logging.debug("looking up released image for {}".format(series))
+            image_name = self.api.released_image(release=series)
+
         return image_name
 
 
