@@ -6,6 +6,7 @@ import random
 import re
 import string
 import sys
+import tarfile
 from typing import Dict, List, Optional, Tuple, Union  # noqa: F401
 
 import pycloudlib  # type: ignore  # noqa: F401
@@ -46,7 +47,7 @@ class UAClientBehaveConfig:
         This indicates whether the image created for this test run should be
         cleaned up when all tests are complete.
     :param machine_type:
-        The default machine_type to test: lxd.container, lxd.vm, azure.pro,
+        The default machine_type to test: lxd-container, lxd-vm, azure.pro,
             azure.generic, aws.pro or aws.generic
     :param private_key_file:
         Optional path to pre-existing private key file to use when connecting
@@ -105,8 +106,6 @@ class UAClientBehaveConfig:
     # This variable is used in .from_environ() but also to emit the "Config
     # options" stanza in __init__
     all_options = boolean_options + str_options
-    cloud_api = None  # type: pycloudlib.cloud.BaseCloud
-    cloud_manager = None  # type: cloud.Cloud
 
     def __init__(
         self,
@@ -116,15 +115,15 @@ class UAClientBehaveConfig:
         destroy_instances: bool = True,
         ephemeral_instance: bool = False,
         snapshot_strategy: bool = False,
-        machine_type: str = "lxd.container",
+        machine_type: str = "lxd-container",
         private_key_file: Optional[str] = None,
         private_key_name: str = "uaclient-integration",
         reuse_image: Optional[str] = None,
         contract_token: Optional[str] = None,
         contract_token_staging: Optional[str] = None,
         contract_token_staging_expired: Optional[str] = None,
-        artifact_dir: Optional[str] = None,
-        install_from: InstallationSource = InstallationSource.DAILY,
+        artifact_dir: str = "artifacts",
+        install_from: InstallationSource = InstallationSource.LOCAL,
         custom_ppa: Optional[str] = None,
         debs_path: Optional[str] = None,
         userdata_file: Optional[str] = None,
@@ -214,47 +213,39 @@ class UAClientBehaveConfig:
         )
         timed_job_tag += "-" + random_suffix
 
+        self.clouds = {
+            "aws": cloud.EC2(
+                cloud_credentials_path=self.cloud_credentials_path,
+                tag=timed_job_tag,
+                timestamp_suffix=False,
+            ),
+            "azure": cloud.Azure(
+                cloud_credentials_path=self.cloud_credentials_path,
+                tag=timed_job_tag,
+                timestamp_suffix=False,
+            ),
+            "gcp": cloud.GCP(
+                cloud_credentials_path=self.cloud_credentials_path,
+                tag=timed_job_tag,
+                timestamp_suffix=False,
+            ),
+            "lxd-vm": cloud.LXDVirtualMachine(
+                cloud_credentials_path=self.cloud_credentials_path,
+            ),
+            "lxd-container": cloud.LXDContainer(
+                cloud_credentials_path=self.cloud_credentials_path,
+            ),
+        }
         if "aws" in self.machine_type:
-            # For AWS, we need to specify on the pycloudlib config file that
-            # the AWS region must be us-east-2. The reason for that is because
-            # our image ids were captured using that region.
-            self.cloud_manager = cloud.EC2(
-                machine_type=self.machine_type,
-                cloud_credentials_path=self.cloud_credentials_path,
-                tag=timed_job_tag,
-                timestamp_suffix=False,
-            )
-            self.cloud = "aws"
+            self.default_cloud = self.clouds["aws"]
         elif "azure" in self.machine_type:
-            self.cloud_manager = cloud.Azure(
-                machine_type=self.machine_type,
-                cloud_credentials_path=self.cloud_credentials_path,
-                tag=timed_job_tag,
-                timestamp_suffix=False,
-            )
-            self.cloud = "azure"
+            self.default_cloud = self.clouds["azure"]
         elif "gcp" in self.machine_type:
-            self.cloud_manager = cloud.GCP(
-                machine_type=self.machine_type,
-                cloud_credentials_path=self.cloud_credentials_path,
-                tag=timed_job_tag,
-                timestamp_suffix=False,
-            )
-            self.cloud = "gcp"
-        elif "lxd.vm" in self.machine_type:
-            self.cloud_manager = cloud.LXDVirtualMachine(
-                machine_type=self.machine_type,
-                cloud_credentials_path=self.cloud_credentials_path,
-            )
-            self.cloud = "lxd.vm"
+            self.default_cloud = self.clouds["gcp"]
+        elif "lxd-vm" in self.machine_type:
+            self.default_cloud = self.clouds["lxd-vm"]
         else:
-            self.cloud_manager = cloud.LXDContainer(
-                machine_type=self.machine_type,
-                cloud_credentials_path=self.cloud_credentials_path,
-            )
-            self.cloud = "lxd"
-
-        self.cloud_api = self.cloud_manager.api
+            self.default_cloud = self.clouds["lxd-container"]
 
         # Finally, print the config options.  This helps users debug the use of
         # config options, and means they'll be included in test logs in CI.
@@ -299,6 +290,9 @@ class UAClientBehaveConfig:
                     bool_value = False
                 kwargs[key] = bool_value
 
+        # userdata should override environment variables
+        kwargs.update(config.userdata)
+
         if "install_from" in kwargs:
             kwargs["install_from"] = InstallationSource(kwargs["install_from"])
 
@@ -329,17 +323,16 @@ def before_all(context: Context) -> None:
             print("   - {} = {}".format(key, value))
     context.series_image_name = {}
     context.series_reuse_image = ""
-    context.config = UAClientBehaveConfig.from_environ(context.config)
-    context.config.cloud_manager.manage_ssh_key()
+    context.pro_config = UAClientBehaveConfig.from_environ(context.config)
     context.snapshots = {}
     context.machines = {}
 
-    if context.config.reuse_image:
+    if context.pro_config.reuse_image:
         series = lxc_get_property(
-            context.config.reuse_image, property_name="series", image=True
+            context.pro_config.reuse_image, property_name="series", image=True
         )
         machine_type = lxc_get_property(
-            context.config.reuse_image,
+            context.pro_config.reuse_image,
             property_name="machine_type",
             image=True,
         )
@@ -347,26 +340,26 @@ def before_all(context: Context) -> None:
             print("Found machine_type: {vm_type}".format(vm_type=machine_type))
         if series is not None:
             context.series_reuse_image = series
-            context.series_image_name[series] = context.config.reuse_image
+            context.series_image_name[series] = context.pro_config.reuse_image
         else:
             print(" Could not check image series. It will not be used. ")
-            context.config.reuse_image = None
+            context.pro_config.reuse_image = None
 
 
 def _should_skip_tags(context: Context, tags: List) -> str:
     """Return a reason if a feature or scenario should be skipped"""
-    machine_type = getattr(context.config, "machine_type", "")
+    machine_type = getattr(context.pro_config, "machine_type", "")
     machine_types = []
 
     for tag in tags:
         parts = tag.split(".")
-        if parts[0] != "uses":
-            continue  # Only process @uses.* tags for skipping:
-        val = context
-        for idx, attr in enumerate(parts[1:], 1):
+        if parts[0] != "uses" or parts[1] != "config":
+            continue  # Only process @uses.config.* tags for skipping:
+        val = context.pro_config
+        for idx, attr in enumerate(parts[2:], 1):
             val = getattr(val, attr, None)
             if attr == "machine_type":
-                curr_machine_type = ".".join(parts[idx + 1 :])
+                curr_machine_type = ".".join(parts[idx + 2 :])
                 machine_types.append(curr_machine_type)
                 if curr_machine_type == machine_type:
                     return ""
@@ -397,9 +390,9 @@ def before_scenario(context: Context, scenario: Scenario):
         scenario.skip(reason=reason)
         return
 
-    filter_series = context.config.filter_series
+    filter_series = context.pro_config.filter_series
     given_a_series_match = re.match(
-        "a `(.*)` machine with ubuntu-advantage-tools installed",
+        "a `([a-z]*)` machine with ubuntu-advantage-tools installed",
         scenario.steps[0].name,
     )
     if filter_series and given_a_series_match:
@@ -415,6 +408,38 @@ def before_scenario(context: Context, scenario: Scenario):
             )
             return
 
+    if hasattr(scenario, "_row") and scenario._row is not None:
+        row_release = scenario._row.get("release")
+        if (
+            row_release
+            and len(filter_series) > 0
+            and row_release not in filter_series
+        ):
+            scenario.skip(
+                reason=(
+                    "Skipping scenario outline series `{series}`."
+                    " Cmdline provided @series tags: {cmdline_series}".format(
+                        series=row_release, cmdline_series=filter_series
+                    )
+                )
+            )
+            return
+        row_machine_type = scenario._row.get("machine_type")
+        if (
+            row_machine_type
+            and context.pro_config.machine_type != "any"
+            and row_machine_type != context.pro_config.machine_type
+        ):
+            scenario.skip(
+                reason=(
+                    "Skipping scenario outline machine_type `{}`."
+                    " Cmdline provided machine_type: {}".format(
+                        row_machine_type, context.pro_config.machine_type
+                    )
+                )
+            )
+            return
+
     # before_step doesn't execute early enough to modify the step
     # so we perform step text surgery here
     # Also, logging capture is not set up when before_scenario is called,
@@ -431,61 +456,30 @@ def before_scenario(context: Context, scenario: Scenario):
             )
 
 
-FAILURE_FILES = (
-    "/etc/ubuntu-advantage/uaclient.log",
-    "/var/log/cloud-init.log",
-    "/var/log/ubuntu-advantage.log",
-    "/var/log/ubuntu-advantage-daemon.log",
-    "/var/log/ubuntu-advantage-timer.log",
-    "/var/lib/cloud/instance/user-data.txt",
-    "/var/lib/cloud/instance/vendor-data.txt",
-)
-FAILURE_CMDS = {
-    "ua-version": ["pro", "version"],
-    "cloud-init-analyze": ["cloud-init", "analyze", "show"],
-    "cloud-init.status": ["cloud-init", "status", "--long"],
-    "status.yaml": ["pro", "status", "--all", "--format=yaml"],
-    "journal.log": ["journalctl", "-b", "0"],
-    "systemd-analyze-blame": ["systemd-analyze", "blame"],
-    "systemctl-status": ["systemctl", "status"],
-    "systemctl-status-ua-auto-attach": [
-        "systemctl",
-        "status",
-        "ua-auto-attach.service",
-    ],
-    "systemctl-status-ua-reboot-cmds": [
-        "systemctl",
-        "status",
-        "ua-reboot-cmds.service",
-    ],
-    "systemctl-status-ubuntu-advantage": [
-        "systemctl",
-        "status",
-        "ubuntu-advantage.service",
-    ],
-    "systemctl-status-apt-news": [
-        "systemctl",
-        "status",
-        "apt-news.service",
-    ],
-}
-
-
 def after_step(context, step):
     """Collect test artifacts in the event of failure."""
     if step.status == "failed":
-        if context.config.artifact_dir:
-            artifacts_dir = context.config.artifact_dir
-        else:
-            artifacts_dir = "artifacts"
-        artifacts_dir = os.path.join(
-            artifacts_dir,
+        logging.warning("STEP FAILED. Collecting logs.")
+        inner_dir = os.path.join(
+            datetime.datetime.now().strftime("%Y-%m-%dT%H-%M-%S"),
             "{}_{}".format(os.path.basename(step.filename), step.line),
         )
+        new_artifacts_dir = os.path.join(
+            context.pro_config.artifact_dir,
+            inner_dir,
+        )
+        if not os.path.exists(new_artifacts_dir):
+            os.makedirs(new_artifacts_dir)
+
+        latest_link_dir = os.path.join(
+            context.pro_config.artifact_dir, "latest"
+        )
+        if os.path.exists(latest_link_dir):
+            os.unlink(latest_link_dir)
+        os.symlink(inner_dir, latest_link_dir)
+
         if hasattr(context, "process"):
-            if not os.path.exists(artifacts_dir):
-                os.makedirs(artifacts_dir)
-            artifact_file = os.path.join(artifacts_dir, "process.log")
+            artifact_file = os.path.join(new_artifacts_dir, "process.log")
             process = context.process
             with open(artifact_file, "w") as stream:
                 stream.write(
@@ -497,35 +491,28 @@ def after_step(context, step):
                 )
 
         if hasattr(context, "machines") and SUT in context.machines:
-            if not os.path.exists(artifacts_dir):
-                os.makedirs(artifacts_dir)
-            for log_file in FAILURE_FILES:
-                artifact_file = os.path.join(
-                    artifacts_dir, os.path.basename(log_file)
+            try:
+                context.machines[SUT].instance.execute(
+                    ["pro", "collect-logs", "-o", "/tmp/logs.tar.gz"],
+                    use_sudo=True,
                 )
-                logging.info(
-                    "-- pull instance:{} {}".format(log_file, artifact_file)
+                context.machines[SUT].instance.execute(
+                    ["chmod", "666", "/tmp/logs.tar.gz"], use_sudo=True
                 )
-                try:
-                    result = context.machines[SUT].instance.execute(
-                        ["cat", log_file], use_sudo=True
-                    )
-                    content = result.stdout if result.ok else ""
-                except RuntimeError:
-                    content = ""
-                with open(artifact_file, "w") as stream:
-                    stream.write(content)
-            for artifact_file, cmd in FAILURE_CMDS.items():
-                result = context.machines[SUT].instance.execute(
-                    cmd, use_sudo=True
+                dest = os.path.join(new_artifacts_dir, "logs.tar.gz")
+                context.machines[SUT].instance.pull_file(
+                    "/tmp/logs.tar.gz", dest
                 )
-                artifact_file = os.path.join(artifacts_dir, artifact_file)
-                with open(artifact_file, "w") as stream:
-                    stream.write(result.stdout)
+                with tarfile.open(dest) as logs_tarfile:
+                    logs_tarfile.extractall(new_artifacts_dir)
+                logging.warning("Done collecting logs.")
+            except Exception as e:
+                logging.error(str(e))
+                logging.warning("Failed to collect logs")
 
 
 def after_all(context):
-    if context.config.image_clean:
+    if context.pro_config.image_clean:
         for key, image in context.series_image_name.items():
             if key == context.series_reuse_image:
                 logging.info(
@@ -533,11 +520,11 @@ def after_all(context):
                     context.series_image_name[key],
                 )
             else:
-                context.config.cloud_api.delete_image(image)
+                context.pro_config.default_cloud.api.delete_image(image)
 
-    if context.config.destroy_instances:
+    if context.pro_config.destroy_instances:
         try:
-            key_pair = context.config.cloud_manager.api.key_pair
+            key_pair = context.pro_config.default_cloud.api.key_pair
             os.remove(key_pair.private_key_path)
             os.remove(key_pair.public_key_path)
         except Exception as e:
@@ -547,7 +534,7 @@ def after_all(context):
 
     if "builder" in context.snapshots:
         try:
-            context.config.cloud_manager.api.delete_image(
+            context.pro_config.default_cloud.api.delete_image(
                 context.snapshots["builder"]
             )
         except RuntimeError as e:
