@@ -1,11 +1,12 @@
 """Tests related to uaclient.entitlement.base module."""
+import copy
 import logging
 from typing import Any, Dict, Optional, Tuple
 
 import mock
 import pytest
 
-from uaclient import messages, util
+from uaclient import messages, system, util
 from uaclient.entitlements import base
 from uaclient.entitlements.entitlement_status import (
     ApplicabilityStatus,
@@ -38,9 +39,14 @@ class ConcreteTestEntitlement(base.UAEntitlement):
         dependent_services=None,
         required_services=None,
         blocking_incompatible_services=None,
+        variant_name="",
         **kwargs
     ):
-        super().__init__(cfg, allow_beta=allow_beta, access_only=access_only)
+        super().__init__(
+            cfg,
+            allow_beta=allow_beta,
+            access_only=access_only,
+        )
         self.supports_access_only = supports_access_only
         self._disable = disable
         self._enable = enable
@@ -49,6 +55,7 @@ class ConcreteTestEntitlement(base.UAEntitlement):
         self._dependent_services = dependent_services
         self._required_services = required_services
         self._blocking_incompatible_services = blocking_incompatible_services
+        self._variant_name = variant_name
 
     def _perform_disable(self, **kwargs):
         self._application_status = (
@@ -72,6 +79,14 @@ class ConcreteTestEntitlement(base.UAEntitlement):
         else:
             return super().blocking_incompatible_services()
 
+    @property
+    def variant_name(self):
+        return self._variant_name
+
+    @property
+    def is_variant(self):
+        return False if not self._variant_name else True
+
 
 @pytest.fixture
 def concrete_entitlement_factory(FakeConfig):
@@ -93,7 +108,8 @@ def concrete_entitlement_factory(FakeConfig):
         enable: bool = False,
         disable: bool = False,
         dependent_services: Tuple[Any, ...] = None,
-        required_services: Tuple[Any, ...] = None
+        required_services: Tuple[Any, ...] = None,
+        variant_name: str = ""
     ) -> ConcreteTestEntitlement:
         cfg = FakeConfig()
         machineToken = {
@@ -125,6 +141,7 @@ def concrete_entitlement_factory(FakeConfig):
             disable=disable,
             dependent_services=dependent_services,
             required_services=required_services,
+            variant_name=variant_name,
         )
 
     return factory
@@ -945,7 +962,10 @@ class TestUaEntitlementProcessContractDeltas:
         ),
     )
     @mock.patch(
-        "uaclient.system.get_platform_info", return_value={"series": "example"}
+        "uaclient.system.get_release_info",
+        return_value=system.ReleaseInfo(
+            distribution="", release="", series="example", pretty_version=""
+        ),
     )
     def test_process_contract_deltas_does_nothing_when_delta_remains_entitled(
         self, m_platform_info, concrete_entitlement_factory, orig_access, delta
@@ -1061,3 +1081,149 @@ class TestUaEntitlementProcessContractDeltas:
             assert 1 == m_enable.call_count
 
         assert entitlement.allow_beta
+
+
+class TestEntitlementCfg:
+    @pytest.mark.parametrize(
+        "variant_name", ((""), ("test-variant"), ("invalid-variant"))
+    )
+    def test_entitlement_cfg_respects_variant(
+        self, variant_name, concrete_entitlement_factory
+    ):
+        entitlement = concrete_entitlement_factory(
+            entitled=True,
+            applicability_status=(ApplicabilityStatus.APPLICABLE, ""),
+            application_status=(ApplicationStatus.DISABLED, ""),
+            variant_name=variant_name,
+        )
+        base_ent_dict = {
+            "entitlement": {
+                "entitled": True,
+                "obligations": {"enableByDefault": False},
+                "affordances": {
+                    "architectures": [
+                        "amd64",
+                        "ppc64el",
+                    ],
+                    "series": ["xenial", "bionic", "focal"],
+                },
+                "directives": {
+                    "additionalPackages": ["test-package"],
+                    "suites": ["xenial", "bionic", "focal"],
+                },
+                "overrides": [
+                    {
+                        "directives": {
+                            "additionalPackages": ["test-package-variant"]
+                        },
+                        "selector": {
+                            "variant": "test-variant",
+                        },
+                    },
+                    {
+                        "directives": {
+                            "additionalPackages": ["test-package-unused"]
+                        },
+                        "selector": {"cloud": "aws", "series": "focal"},
+                    },
+                ],
+                "type": "test",
+            }
+        }
+
+        expected_entitlement = copy.deepcopy(base_ent_dict)
+        if variant_name == "test-variant":
+            expected_entitlement["entitlement"]["directives"][
+                "additionalPackages"
+            ] = ["test-package-variant"]
+
+        with mock.patch.object(
+            entitlement, "_base_entitlement_cfg"
+        ) as m_ent_cfg:
+            m_ent_cfg.return_value = base_ent_dict
+            actual_entitlement = entitlement.entitlement_cfg
+
+        assert expected_entitlement == actual_entitlement
+
+
+class TestVariant:
+    @pytest.mark.parametrize(
+        "contract_variants",
+        (
+            ([]),
+            (["not-found-variant"]),
+            (["test_variant"]),
+            (["test_variant", "test_variant2"]),
+        ),
+    )
+    @mock.patch("uaclient.entitlements.base.UAEntitlement._get_variants")
+    @mock.patch(
+        "uaclient.entitlements.base.UAEntitlement._get_contract_variants"
+    )
+    def test_variant_property(
+        self,
+        m_get_contract_variants,
+        m_get_variants,
+        contract_variants,
+        concrete_entitlement_factory,
+    ):
+        entitlement = concrete_entitlement_factory()
+        service_variants = {"test_variant": "test", "generic": "generic"}
+        m_get_contract_variants.return_value = contract_variants
+        m_get_variants.return_value = service_variants
+        actual_variants = entitlement.variants
+
+        expected_variants = (
+            {} if "test_variant" not in contract_variants else service_variants
+        )
+        assert expected_variants == actual_variants
+        assert 1 == m_get_contract_variants.call_count
+        assert 1 == m_get_variants.call_count
+
+
+class TestGetContractVariant:
+    @pytest.mark.parametrize(
+        "entitlement_cfg",
+        (
+            ({}),
+            (
+                {
+                    "entitlement": {
+                        "overrides": [
+                            {
+                                "selector": {
+                                    "variant": "test1",
+                                },
+                            },
+                            {
+                                "selector": {
+                                    "variant": "test2",
+                                }
+                            },
+                            {
+                                "selector": {
+                                    "cloud": "cloud",
+                                },
+                            },
+                        ],
+                    }
+                }
+            ),
+        ),
+    )
+    @mock.patch(
+        "uaclient.entitlements.base.UAEntitlement._base_entitlement_cfg"
+    )
+    def test_get_contract_variant(
+        self, m_base_ent_cfg, entitlement_cfg, concrete_entitlement_factory
+    ):
+        entitlement = concrete_entitlement_factory()
+        m_base_ent_cfg.return_value = entitlement_cfg
+
+        actual_contract_variants = entitlement._get_contract_variants()
+        expected_contract_variants = (
+            set() if not entitlement_cfg else set(["test1", "test2"])
+        )
+
+        assert expected_contract_variants == actual_contract_variants
+        assert 1 == m_base_ent_cfg.call_count
