@@ -5,7 +5,6 @@ import copy
 import io
 import logging
 from functools import partial
-from types import MappingProxyType
 
 import mock
 import pytest
@@ -25,15 +24,6 @@ from uaclient.entitlements.livepatch import (
 from uaclient.entitlements.tests.conftest import machine_token
 from uaclient.snap import SNAP_CMD
 
-PLATFORM_INFO_SUPPORTED = MappingProxyType(
-    {
-        "arch": "x86_64",
-        "kernel": "4.4.0-00-generic",
-        "series": "xenial",
-        "version": "16.04 LTS (Xenial Xerus)",
-    }
-)
-
 M_PATH = "uaclient.entitlements.livepatch."  # mock path
 M_LIVEPATCH_STATUS = M_PATH + "LivepatchEntitlement.application_status"
 DISABLED_APP_STATUS = (ApplicationStatus.DISABLED, "")
@@ -97,9 +87,9 @@ class TestLivepatchUserFacingStatus:
         entitlement = livepatch_entitlement_factory(affordances=affordances)
 
         with mock.patch(
-            "uaclient.system.get_platform_info"
-        ) as m_platform_info:
-            m_platform_info.return_value = PLATFORM_INFO_SUPPORTED
+            "uaclient.system.get_release_info"
+        ) as m_get_release_info:
+            m_get_release_info.return_value = mock.MagicMock(series="xenial")
             uf_status, details = entitlement.user_facing_status()
         assert uf_status == UserFacingStatus.INAPPLICABLE
         expected_details = "Cannot install Livepatch on a container."
@@ -115,9 +105,9 @@ class TestLivepatchUserFacingStatus:
         entitlement.cfg.machine_token_file.write(no_entitlements)
 
         with mock.patch(
-            "uaclient.system.get_platform_info"
-        ) as m_platform_info:
-            m_platform_info.return_value = PLATFORM_INFO_SUPPORTED
+            "uaclient.system.get_release_info"
+        ) as m_get_release_info:
+            m_get_release_info.return_value = mock.MagicMock(series="xenial")
             uf_status, details = entitlement.user_facing_status()
         assert uf_status == UserFacingStatus.UNAVAILABLE
         assert "Livepatch is not entitled" == details.msg
@@ -193,8 +183,10 @@ class TestLivepatchEntitlementCanEnable:
         "supported_kernel_ver",
         (
             system.KernelInfo(
+                uname_machine_arch="",
                 uname_release="4.4.0-00-generic",
                 proc_version_signature_version="",
+                build_date=None,
                 major=4,
                 minor=4,
                 patch=0,
@@ -202,8 +194,10 @@ class TestLivepatchEntitlementCanEnable:
                 flavor="generic",
             ),
             system.KernelInfo(
+                uname_machine_arch="",
                 uname_release="5.0.0-00-generic",
                 proc_version_signature_version="",
+                build_date=None,
                 major=5,
                 minor=0,
                 patch=0,
@@ -211,8 +205,10 @@ class TestLivepatchEntitlementCanEnable:
                 flavor="generic",
             ),
             system.KernelInfo(
+                uname_machine_arch="",
                 uname_release="4.19.0-00-generic",
                 proc_version_signature_version="",
+                build_date=None,
                 major=4,
                 minor=19,
                 patch=0,
@@ -221,15 +217,17 @@ class TestLivepatchEntitlementCanEnable:
             ),
         ),
     )
+    @mock.patch("uaclient.system.get_dpkg_arch", return_value="x86_64")
     @mock.patch("uaclient.system.get_kernel_info")
     @mock.patch(
-        "uaclient.system.get_platform_info",
-        return_value=PLATFORM_INFO_SUPPORTED,
+        "uaclient.system.get_release_info",
+        return_value=mock.MagicMock(series="xenial"),
     )
     def test_can_enable_true_on_entitlement_inactive(
         self,
-        _m_platform,
+        _m_get_release_info,
         m_kernel_info,
+        _m_dpkg_arch,
         _m_is_container,
         _m_livepatch_status,
         _m_fips_status,
@@ -245,21 +243,31 @@ class TestLivepatchEntitlementCanEnable:
         assert ("", "") == capsys.readouterr()
         assert [mock.call()] == m_container.call_args_list
 
+    @mock.patch(
+        "uaclient.system.get_release_info",
+        return_value=mock.MagicMock(series="xenial"),
+    )
+    @mock.patch(
+        "uaclient.system.get_kernel_info",
+        return_value=mock.MagicMock(uname_release="4.2.9-00-generic"),
+    )
     def test_can_enable_false_on_containers(
-        self, m_is_container, _m_livepatch_status, _m_fips_status, entitlement
+        self,
+        _m_get_kernel_info,
+        _m_get_release_info,
+        m_is_container,
+        _m_livepatch_status,
+        _m_fips_status,
+        entitlement,
     ):
         """When is_container is True, can_enable returns False."""
-        unsupported_min_kernel = copy.deepcopy(dict(PLATFORM_INFO_SUPPORTED))
-        unsupported_min_kernel["kernel"] = "4.2.9-00-generic"
-        with mock.patch("uaclient.system.get_platform_info") as m_platform:
-            m_platform.return_value = unsupported_min_kernel
-            m_is_container.return_value = True
-            entitlement = LivepatchEntitlement(entitlement.cfg)
-            result, reason = entitlement.can_enable()
-            assert False is result
-            assert CanEnableFailureReason.INAPPLICABLE == reason.reason
-            msg = "Cannot install Livepatch on a container."
-            assert msg == reason.message.msg
+        m_is_container.return_value = True
+        entitlement = LivepatchEntitlement(entitlement.cfg)
+        result, reason = entitlement.can_enable()
+        assert False is result
+        assert CanEnableFailureReason.INAPPLICABLE == reason.reason
+        msg = "Cannot install Livepatch on a container."
+        assert msg == reason.message.msg
 
 
 class TestLivepatchProcessContractDeltas:
@@ -409,7 +417,7 @@ class TestLivepatchEntitlementEnable:
 
     @pytest.mark.parametrize("caplog_text", [logging.DEBUG], indirect=True)
     @pytest.mark.parametrize("apt_update_success", (True, False))
-    @mock.patch("uaclient.system.get_platform_info")
+    @mock.patch("uaclient.system.get_release_info")
     @mock.patch("uaclient.system.subp")
     @mock.patch("uaclient.contract.apply_contract_overrides")
     @mock.patch("uaclient.apt.run_apt_install_command")
@@ -428,7 +436,7 @@ class TestLivepatchEntitlementEnable:
         m_run_apt_install,
         _m_contract_overrides,
         m_subp,
-        _m_get_platform_info,
+        _m_get_release_info,
         m_livepatch_proxy,
         m_snap_proxy,
         m_validate_proxy,
@@ -478,7 +486,7 @@ class TestLivepatchEntitlementEnable:
         assert m_snap_proxy.call_count == 1
         assert m_livepatch_proxy.call_count == 1
 
-    @mock.patch("uaclient.system.get_platform_info")
+    @mock.patch("uaclient.system.get_release_info")
     @mock.patch("uaclient.system.subp")
     @mock.patch("uaclient.contract.apply_contract_overrides")
     @mock.patch(
@@ -496,7 +504,7 @@ class TestLivepatchEntitlementEnable:
         m_which,
         _m_contract_overrides,
         m_subp,
-        _m_get_platform_info,
+        _m_get_release_info,
         m_livepatch_proxy,
         m_snap_proxy,
         m_validate_proxy,
@@ -569,7 +577,7 @@ class TestLivepatchEntitlementEnable:
         assert m_snap_proxy.call_count == 0
         assert m_livepatch_proxy.call_count == 0
 
-    @mock.patch("uaclient.system.get_platform_info")
+    @mock.patch("uaclient.system.get_release_info")
     @mock.patch("uaclient.system.subp")
     @mock.patch("uaclient.contract.apply_contract_overrides")
     @mock.patch(
@@ -586,7 +594,7 @@ class TestLivepatchEntitlementEnable:
         m_which,
         _m_contract_overrides,
         m_subp,
-        _m_get_platform_info,
+        _m_get_release_info,
         m_livepatch_proxy,
         m_snap_proxy,
         m_validate_proxy,
@@ -625,7 +633,7 @@ class TestLivepatchEntitlementEnable:
         assert m_snap_proxy.call_count == 1
         assert m_livepatch_proxy.call_count == 1
 
-    @mock.patch("uaclient.system.get_platform_info")
+    @mock.patch("uaclient.system.get_release_info")
     @mock.patch("uaclient.system.subp")
     @mock.patch("uaclient.contract.apply_contract_overrides")
     @mock.patch(
@@ -642,7 +650,7 @@ class TestLivepatchEntitlementEnable:
         m_which,
         _m_contract_overrides,
         m_subp,
-        _m_get_platform_info,
+        _m_get_release_info,
         m_livepatch_proxy,
         m_snap_proxy,
         m_validate_proxy,
@@ -865,41 +873,40 @@ class TestLivepatchEntitlementEnable:
 
 class TestLivepatchApplicationStatus:
     @pytest.mark.parametrize("which_result", (("/path/to/exe"), (None)))
-    @pytest.mark.parametrize("subp_raise_exception", ((True), (False)))
+    @pytest.mark.parametrize(
+        "livepatch_status_result",
+        (
+            (None),
+            (
+                livepatch.LivepatchStatusStatus(
+                    kernel=None, livepatch=None, supported=None
+                )
+            ),
+        ),
+    )
     @mock.patch("uaclient.system.which")
-    @mock.patch("uaclient.system.subp")
+    @mock.patch("uaclient.livepatch.status")
     def test_application_status(
-        self, m_subp, m_which, subp_raise_exception, which_result, entitlement
+        self,
+        m_livepatch_status,
+        m_which,
+        livepatch_status_result,
+        which_result,
+        entitlement,
     ):
         m_which.return_value = which_result
-
-        if subp_raise_exception:
-            m_subp.side_effect = exceptions.ProcessExecutionError("error msg")
+        m_livepatch_status.return_value = livepatch_status_result
 
         status, details = entitlement.application_status()
 
         if not which_result:
             assert status == ApplicationStatus.DISABLED
             assert "canonical-livepatch snap is not installed." in details.msg
-        elif subp_raise_exception:
+        elif livepatch_status_result is None:
             assert status == ApplicationStatus.DISABLED
-            assert "error msg" in details.msg
+            assert (
+                messages.LIVEPATCH_APPLICATION_STATUS_CLIENT_FAILURE == details
+            )
         else:
             assert status == ApplicationStatus.ENABLED
             assert details is None
-
-    @mock.patch("time.sleep")
-    @mock.patch("uaclient.system.which", return_value="/path/to/exe")
-    def test_status_command_retry_on_application_status(
-        self, m_which, m_sleep, entitlement
-    ):
-        from uaclient import system
-
-        with mock.patch.object(system, "_subp") as m_subp:
-            m_subp.side_effect = exceptions.ProcessExecutionError("error msg")
-            status, details = entitlement.application_status()
-
-            assert m_subp.call_count == 3
-            assert m_sleep.call_count == 2
-            assert status == ApplicationStatus.DISABLED
-            assert "error msg" in details.msg
