@@ -7,7 +7,7 @@ from uaclient.entitlements.entitlement_status import ApplicationStatus
 from uaclient.exceptions import NonRootUserError, UserFacingError
 
 HELP_OUTPUT = """\
-usage: pro set <key>=<value> [flags]
+usage: pro config set <key>=<value> [flags]
 
 Set and apply Ubuntu Pro configuration settings
 
@@ -16,7 +16,8 @@ positional arguments:
                   must be one of: http_proxy, https_proxy, apt_http_proxy,
                   apt_https_proxy, ua_apt_http_proxy, ua_apt_https_proxy,
                   global_apt_http_proxy, global_apt_https_proxy,
-                  update_messaging_timer, update_status_timer, metering_timer
+                  update_messaging_timer, metering_timer, apt_news,
+                  apt_news_url
 
 Flags:
   -h, --help      show this help message and exit
@@ -24,7 +25,6 @@ Flags:
 M_LIVEPATCH = "uaclient.entitlements.livepatch."
 
 
-@mock.patch("uaclient.cli.os.getuid", return_value=0)
 @mock.patch("uaclient.cli.setup_logging")
 class TestMainConfigSet:
     @pytest.mark.parametrize(
@@ -37,7 +37,7 @@ class TestMainConfigSet:
                 " apt_http_proxy, apt_https_proxy, ua_apt_http_proxy,"
                 " ua_apt_https_proxy, global_apt_http_proxy,"
                 " global_apt_https_proxy, update_messaging_timer,"
-                " update_status_timer, metering_timer",
+                " metering_timer",
             ),
             (
                 "http_proxys=",
@@ -45,7 +45,7 @@ class TestMainConfigSet:
                 " apt_http_proxy, apt_https_proxy, ua_apt_http_proxy,"
                 " ua_apt_https_proxy, global_apt_http_proxy,"
                 " global_apt_https_proxy, update_messaging_timer,"
-                " update_status_timer, metering_timer",
+                " metering_timer",
             ),
             (
                 "=value",
@@ -53,7 +53,7 @@ class TestMainConfigSet:
                 " apt_http_proxy, apt_https_proxy, ua_apt_http_proxy,"
                 " ua_apt_https_proxy, global_apt_http_proxy,"
                 " global_apt_https_proxy, update_messaging_timer,"
-                " update_status_timer, metering_timer",
+                " metering_timer",
             ),
         ),
     )
@@ -62,7 +62,6 @@ class TestMainConfigSet:
         self,
         _m_resources,
         _logging,
-        _getuid,
         kv_pair,
         err_msg,
         capsys,
@@ -83,15 +82,14 @@ class TestMainConfigSet:
         assert err_msg in err
 
 
-@mock.patch("uaclient.config.UAConfig.write_cfg")
-@mock.patch("uaclient.cli.os.getuid", return_value=0)
+@mock.patch("uaclient.config.state_files.user_config_file.write")
 @mock.patch("uaclient.cli.contract.get_available_resources")
 class TestActionConfigSet:
+    @mock.patch("uaclient.util.we_are_currently_root", return_value=False)
     def test_set_error_on_non_root_user(
-        self, _m_resources, getuid, _write_cfg, FakeConfig
+        self, _m_resources, _we_are_currently_root, _write, FakeConfig
     ):
         """Root is required to run pro config set."""
-        getuid.return_value = 1
         args = mock.MagicMock(key_value_pair="something=1")
         cfg = FakeConfig()
         with pytest.raises(NonRootUserError):
@@ -106,7 +104,7 @@ class TestActionConfigSet:
             ("https_proxy", "https://proxy", True),
         ),
     )
-    @mock.patch(M_LIVEPATCH + "configure_livepatch_proxy")
+    @mock.patch("uaclient.livepatch.configure_livepatch_proxy")
     @mock.patch(M_LIVEPATCH + "LivepatchEntitlement.application_status")
     @mock.patch("uaclient.snap.configure_snap_proxy")
     @mock.patch("uaclient.util.validate_proxy")
@@ -117,8 +115,7 @@ class TestActionConfigSet:
         livepatch_status,
         configure_livepatch_proxy,
         _m_resources,
-        _getuid,
-        _write_cfg,
+        _write,
         key,
         value,
         livepatch_enabled,
@@ -181,8 +178,7 @@ class TestActionConfigSet:
         validate_proxy,
         configure_apt_proxy,
         _m_resources,
-        _getuid,
-        _write_cfg,
+        _write,
         key,
         value,
         scope,
@@ -288,8 +284,7 @@ class TestActionConfigSet:
         validate_proxy,
         configure_apt_proxy,
         _m_resources,
-        _getuid,
-        _write_cfg,
+        _write,
         key,
         value,
         scope,
@@ -399,8 +394,7 @@ class TestActionConfigSet:
         validate_proxy,
         configure_apt_proxy,
         _m_resources,
-        _getuid,
-        _write_cfg,
+        _write,
         key,
         value,
         scope,
@@ -463,8 +457,7 @@ class TestActionConfigSet:
         self,
         setup_apt_proxy,
         _m_resources,
-        _getuid,
-        _write_cfg,
+        _write,
         key,
         value,
         scope,
@@ -503,8 +496,7 @@ class TestActionConfigSet:
         self,
         setup_apt_proxy,
         _m_resources,
-        _getuid,
-        _write_cfg,
+        _write,
         key,
         value,
         scope,
@@ -522,9 +514,7 @@ class TestActionConfigSet:
         assert 1 == setup_apt_proxy.call_count
         assert [mock.call(**kwargs)] == setup_apt_proxy.call_args_list
 
-    def test_set_timer_interval(
-        self, _m_resources, _getuid, _write_cfg, FakeConfig
-    ):
+    def test_set_timer_interval(self, _m_resources, _write, FakeConfig):
         args = mock.MagicMock(key_value_pair="update_messaging_timer=28800")
         cfg = FakeConfig()
         action_config_set(args, cfg=cfg)
@@ -532,7 +522,11 @@ class TestActionConfigSet:
 
     @pytest.mark.parametrize("invalid_value", ("notanumber", -1))
     def test_error_when_interval_is_not_valid(
-        self, _m_resources, _getuid, _write_cfg, FakeConfig, invalid_value
+        self,
+        _m_resources,
+        _write,
+        FakeConfig,
+        invalid_value,
     ):
         args = mock.MagicMock(
             key_value_pair="update_messaging_timer={}".format(invalid_value)
