@@ -31,15 +31,19 @@ Flags:
                        realtime-kernel.
   --beta               allow beta service to be enabled
   --format {cli,json}  output enable in the specified format (default: cli)
+  --variant VARIANT    The name of the variant to use when enabling the
+                       service
 """
 
 
 @mock.patch("uaclient.contract.request_updated_contract")
 class TestActionEnable:
+    @mock.patch("uaclient.cli.setup_logging")
     @mock.patch("uaclient.cli.contract.get_available_resources")
     def test_enable_help(
         self,
         _m_resources,
+        _m_setup_logging,
         _request_updated_contract,
         capsys,
         FakeConfig,
@@ -64,6 +68,7 @@ class TestActionEnable:
         capsys,
         event,
         FakeConfig,
+        tmpdir,
     ):
         """Check that a UID != 0 will receive a message and exit non-zero"""
         args = mock.MagicMock()
@@ -72,6 +77,12 @@ class TestActionEnable:
         with pytest.raises(exceptions.NonRootUserError):
             action_enable(args, cfg=cfg)
 
+        default_get_user_log_file = tmpdir.join("default.log").strpath
+        defaults_ret = {
+            "log_level": "debug",
+            "log_file": default_get_user_log_file,
+        }
+
         with pytest.raises(SystemExit):
             with mock.patch(
                 "sys.argv",
@@ -88,7 +99,15 @@ class TestActionEnable:
                     "uaclient.config.UAConfig",
                     return_value=FakeConfig(),
                 ):
-                    main()
+                    with mock.patch(
+                        "uaclient.log.get_user_log_file",
+                        return_value=tmpdir.join("user.log").strpath,
+                    ):
+                        with mock.patch.dict(
+                            "uaclient.cli.defaults.CONFIG_DEFAULTS",
+                            defaults_ret,
+                        ):
+                            main()
 
         expected_message = messages.NONROOT_USER
         expected = {
@@ -272,6 +291,8 @@ class TestActionEnable:
         args = mock.MagicMock()
         args.service = ["bogus"]
         args.command = "enable"
+        args.access_only = False
+
         with pytest.raises(exceptions.UserFacingError) as err:
             action_enable(args, cfg)
 
@@ -402,6 +423,7 @@ class TestActionEnable:
         args.assume_yes = assume_yes
         args.beta = False
         args.access_only = False
+        args.variant = ""
 
         with mock.patch(
             "uaclient.entitlements.entitlement_factory",
@@ -454,7 +476,7 @@ class TestActionEnable:
         m_ent3_obj = m_ent3_cls.return_value
         m_ent3_obj.enable.return_value = (True, None)
 
-        def factory_side_effect(cfg, name, not_found_okay=True):
+        def factory_side_effect(cfg, name, variant):
             if name == "ent2":
                 return m_ent2_cls
             if name == "ent3":
@@ -471,6 +493,7 @@ class TestActionEnable:
         args_mock.access_only = False
         args_mock.assume_yes = assume_yes
         args_mock.beta = False
+        args_mock.variant = ""
 
         expected_msg = "One moment, checking your subscription first\n"
 
@@ -580,8 +603,9 @@ class TestActionEnable:
         args_mock.access_only = False
         args_mock.assume_yes = assume_yes
         args_mock.beta = beta_flag
+        args_mock.variant = ""
 
-        def factory_side_effect(cfg, name, not_found_okay=True):
+        def factory_side_effect(cfg, name, variant):
             if name == "ent2":
                 return m_ent2_cls
             if name == "ent3":
@@ -703,6 +727,7 @@ class TestActionEnable:
         args_mock.service = ["ent1"]
         args_mock.assume_yes = False
         args_mock.beta = False
+        args_mock.access_only = False
 
         with mock.patch(
             "uaclient.entitlements.entitlement_factory",
@@ -770,6 +795,7 @@ class TestActionEnable:
         args_mock = mock.MagicMock()
         args_mock.service = service
         args_mock.beta = beta
+        args_mock.access_only = False
 
         with pytest.raises(exceptions.UserFacingError) as err:
             fake_stdout = io.StringIO()
@@ -844,6 +870,7 @@ class TestActionEnable:
         args_mock.assume_yes = False
         args_mock.beta = allow_beta
         args_mock.service = ["testitlement"]
+        args_mock.variant = ""
 
         with mock.patch(
             "uaclient.entitlements.entitlement_factory",
@@ -930,3 +957,14 @@ class TestActionEnable:
             "warnings": [],
         }
         assert expected == json.loads(fake_stdout.getvalue())
+
+    def test_access_only_cannot_be_used_together_with_variant(
+        self, _m_get_available_resources, FakeConfig
+    ):
+        cfg = FakeConfig.for_attached_machine()
+        args_mock = mock.MagicMock()
+        args_mock.access_only = True
+        args_mock.variant = "variant"
+
+        with pytest.raises(exceptions.InvalidOptionCombination):
+            action_enable(args_mock, cfg)
