@@ -110,6 +110,8 @@ esm-apps         yes        Expanded Security Maintenance for Applications
 esm-infra        yes        Expanded Security Maintenance for Infrastructure
 livepatch        yes        Canonical Livepatch service
 
+For a list of all Ubuntu Pro services, run 'pro status --all'
+
 This machine is not attached to an Ubuntu Pro subscription.
 See https://ubuntu.com/pro
 """  # noqa: E501
@@ -140,6 +142,7 @@ esm-apps         no        {dash}         Expanded Security Maintenance for Appl
 esm-infra        no        {dash}         Expanded Security Maintenance for Infrastructure
 livepatch        no        {dash}         Canonical Livepatch service
 {notices}{features}
+For a list of all Ubuntu Pro services, run 'pro status --all'
 Enable services with: pro enable <service>
 
                 Account: test_account
@@ -340,8 +343,10 @@ Flags:
     return_value=RESPONSE_CONTRACT_INFO,
 )
 class TestActionStatus:
+    @mock.patch(M_PATH + "setup_logging")
     def test_status_help(
         self,
+        _m_setup_logging,
         _m_get_contract_information,
         _m_get_available_resources,
         _m_should_reboot,
@@ -630,6 +635,7 @@ class TestActionStatus:
             "config": {
                 "data_dir": mock.ANY,
                 "ua_config": mock.ANY,
+                "log_file": mock.ANY,
             },
             "simulated": False,
             "errors": [],
@@ -754,6 +760,7 @@ class TestActionStatus:
             "config": {
                 "data_dir": mock.ANY,
                 "ua_config": mock.ANY,
+                "log_file": mock.ANY,
             },
             "simulated": False,
             "errors": [],
@@ -921,6 +928,7 @@ class TestActionStatus:
             "config": {
                 "data_dir": mock.ANY,
                 "ua_config": mock.ANY,
+                "log_file": mock.ANY,
             },
             "errors": [],
             "warnings": [],
