@@ -175,7 +175,6 @@ class TestNotices:
         removes,
         expected,
     ):
-
         for notice_ in notices_:
             notices.add(*notice_)
         for label in removes:
@@ -303,7 +302,7 @@ class TestDataPath:
         self, FakeConfig
     ):
         cfg = FakeConfig({"data_dir": "/my/d"})
-        cfg.data_paths["test_path"] = DataPath("test_path", False, False)
+        cfg.data_paths["test_path"] = DataPath("test_path", False)
         assert "/my/d/test_path" == cfg.data_path("test_path")
 
 
@@ -441,8 +440,8 @@ class TestWriteCache:
     @pytest.mark.parametrize(
         "datapath,mode",
         (
-            (DataPath("path", False, False), 0o644),
-            (DataPath("path", True, False), 0o600),
+            (DataPath("path", False), 0o644),
+            (DataPath("path", True), 0o600),
         ),
     )
     def test_permissions(self, FakeConfig, datapath, mode):
@@ -598,7 +597,7 @@ class TestDeleteCache:
         cfg.machine_token_file.delete()
         assert {} == cfg.machine_token_file.entitlements
 
-    def test_delete_cache_removes_all_data_path_files_with_delete_permanent(
+    def test_delete_cache_removes_all_data_path_files(
         self, tmpdir, FakeConfig
     ):
         """Any cached files defined in cfg.data_paths will be removed."""
@@ -619,7 +618,7 @@ class TestDeleteCache:
             )
         )
         assert len(odd_keys) == len(present_files)
-        cfg.delete_cache(delete_permanent=True)
+        cfg.delete_cache()
         dirty_files = list(
             itertools.chain(
                 *[walk_entry[2] for walk_entry in os.walk(tmpdir.strpath)]
@@ -629,39 +628,6 @@ class TestDeleteCache:
             ", ".join(dirty_files)
         )
 
-    def test_delete_cache_ignores_permanent_data_path_files(
-        self, tmpdir, FakeConfig
-    ):
-        """Any cached files defined in cfg.data_paths will be removed."""
-        cfg = FakeConfig()
-        for key in cfg.data_paths.keys():
-            if key == "notices":
-                # notices key expects specific list or lists format
-                value = [[key, key]]
-            else:
-                value = key
-            cfg.write_cache(key, value)
-
-        num_permanent_files = len(
-            [v for v in cfg.data_paths.values() if v.permanent]
-        )
-        present_files = list(
-            itertools.chain(
-                *[walk_entry[2] for walk_entry in os.walk(tmpdir.strpath)]
-            )
-        )
-        assert len(cfg.data_paths.keys()) == len(present_files)
-        cfg.delete_cache()
-        cfg.machine_token_file.delete()
-        dirty_files = list(
-            itertools.chain(
-                *[walk_entry[2] for walk_entry in os.walk(tmpdir.strpath)]
-            )
-        )
-        assert num_permanent_files == len(
-            dirty_files
-        ), "{} files not deleted".format(", ".join(dirty_files))
-
     def test_delete_cache_ignores_files_not_defined_in_data_paths(
         self, tmpdir, FakeConfig
     ):
@@ -1028,11 +994,9 @@ class TestParseConfig:
     def test_parse_config_uses_defaults_when_no_config_present(
         self, _m_resources, m_exists
     ):
-        cwd = os.getcwd()
         with mock.patch.dict("uaclient.config.os.environ", values={}):
             config, _ = parse_config()
         expected_calls = [
-            mock.call("{}/uaclient.conf".format(cwd)),
             mock.call("/etc/ubuntu-advantage/uaclient.conf"),
         ]
         assert expected_calls == m_exists.call_args_list
@@ -1148,7 +1112,7 @@ class TestParseConfig:
         self, m_load_file, m_path_exists
     ):
         m_load_file.return_value = "test: true\nfoo: bar"
-        m_path_exists.side_effect = [False, False, True]
+        m_path_exists.side_effect = [False, True]
 
         user_values = {"UA_FEATURES_TEST": "test.yaml"}
         with mock.patch.dict("uaclient.config.os.environ", values=user_values):
@@ -1388,19 +1352,9 @@ class TestGetConfigPath:
         ):
             assert "test" == get_config_path()
 
-    @mock.patch("uaclient.config.os.path.join", return_value="test123")
-    @mock.patch("uaclient.config.os.path.exists", return_value=True)
-    def test_get_config_path_from_local_dir(self, _m_exists, _m_join):
-        with mock.patch.dict("uaclient.config.os.environ", values={}):
-            assert "test123" == get_config_path()
-            assert _m_join.call_count == 1
-            assert _m_exists.call_count == 1
-
-    @mock.patch("uaclient.config.os.path.exists", return_value=False)
-    def test_get_default_config_path(self, _m_exists):
+    def test_get_default_config_path(self):
         with mock.patch.dict("uaclient.config.os.environ", values={}):
             assert DEFAULT_CONFIG_FILE == get_config_path()
-            assert _m_exists.call_count == 1
 
 
 class TestCheckLockInfo:
