@@ -1,8 +1,15 @@
+import logging
+
 import mock
 import pytest
 
 from lib.auto_attach import check_cloudinit_userdata_for_ua_info, main
-from uaclient.exceptions import AlreadyAttachedOnPROError
+from uaclient import messages
+from uaclient.api.exceptions import (
+    AlreadyAttachedError,
+    AutoAttachDisabledError,
+)
+from uaclient.daemon import AUTO_ATTACH_STATUS_MOTD_FILE
 
 
 class TestCheckCloudinitUserdataForUAInfo:
@@ -46,6 +53,8 @@ class TestCheckCloudinitUserdataForUAInfo:
         assert expected is check_cloudinit_userdata_for_ua_info()
 
 
+@mock.patch("lib.auto_attach.system.ensure_file_absent")
+@mock.patch("lib.auto_attach.system.write_file")
 class TestMain:
     @pytest.mark.parametrize(
         "ubuntu_advantage_in_userdata",
@@ -55,11 +64,13 @@ class TestMain:
         ),
     )
     @mock.patch("lib.auto_attach.check_cloudinit_userdata_for_ua_info")
-    @mock.patch("lib.auto_attach.action_auto_attach")
+    @mock.patch("lib.auto_attach.full_auto_attach")
     def test_main(
         self,
-        m_cli_auto_attach,
+        m_api_full_auto_attach,
         m_check_cloudinit,
+        m_write_file,
+        m_ensure_file_absent,
         ubuntu_advantage_in_userdata,
         caplog_text,
         FakeConfig,
@@ -68,9 +79,17 @@ class TestMain:
         main(cfg=FakeConfig())
 
         if not ubuntu_advantage_in_userdata:
-            assert 1 == m_cli_auto_attach.call_count
+            assert [
+                mock.call(
+                    AUTO_ATTACH_STATUS_MOTD_FILE, messages.AUTO_ATTACH_RUNNING
+                )
+            ] == m_write_file.call_args_list
+            assert 1 == m_api_full_auto_attach.call_count
+            assert [
+                mock.call(AUTO_ATTACH_STATUS_MOTD_FILE)
+            ] == m_ensure_file_absent.call_args_list
         else:
-            assert 0 == m_cli_auto_attach.call_count
+            assert 0 == m_api_full_auto_attach.call_count
             assert (
                 "cloud-init userdata has ubuntu-advantage key."
             ) in caplog_text()
@@ -79,20 +98,48 @@ class TestMain:
                 "to setup and configure auto-attach"
             ) in caplog_text()
 
+    @pytest.mark.parametrize("caplog_text", [logging.DEBUG], indirect=True)
+    @pytest.mark.parametrize(
+        "api_side_effect, log_msg",
+        [
+            (
+                AlreadyAttachedError("test_account"),
+                "This machine is already attached to 'test_account'",
+            ),
+            (
+                AutoAttachDisabledError,
+                "Skipping auto-attach. Config disable_auto_attach is set.\n",
+            ),
+        ],
+    )
     @mock.patch("lib.auto_attach.check_cloudinit_userdata_for_ua_info")
-    @mock.patch("lib.auto_attach.action_auto_attach")
-    def test_main_when_already_attached(
+    @mock.patch("lib.auto_attach.full_auto_attach")
+    def test_main_handles_errors(
         self,
-        m_cli_auto_attach,
+        m_api_full_auto_attach,
         m_check_cloudinit,
-        FakeConfig,
+        m_write_file,
+        m_ensure_file_absent,
+        api_side_effect,
+        log_msg,
         caplog_text,
+        FakeConfig,
     ):
+        cfg = FakeConfig.for_attached_machine()
         m_check_cloudinit.return_value = False
-        m_cli_auto_attach.side_effect = AlreadyAttachedOnPROError()
-        main(cfg=FakeConfig())
+        m_api_full_auto_attach.side_effect = api_side_effect
+
+        main(cfg=cfg)
 
         assert (
-            "Skipping auto-attach: Instance is already attached."
-            in caplog_text()
+            mock.call(
+                AUTO_ATTACH_STATUS_MOTD_FILE, messages.AUTO_ATTACH_RUNNING
+            )
+            in m_write_file.call_args_list
+        )
+        assert m_api_full_auto_attach.call_count == 1
+        assert log_msg in caplog_text()
+        assert (
+            mock.call(AUTO_ATTACH_STATUS_MOTD_FILE)
+            in m_ensure_file_absent.call_args_list
         )
