@@ -12,6 +12,7 @@ from uaclient.livepatch import (
     LivepatchPatchFixStatus,
     LivepatchPatchStatus,
     LivepatchStatusStatus,
+    LivepatchSupport,
     UALivepatchClient,
     _on_supported_kernel_api,
     _on_supported_kernel_cache,
@@ -59,6 +60,7 @@ class TestStatus:
                                         "Kernel": "installed-kernel-generic",
                                         "Livepatch": {
                                             "State": "nothing-to-apply",
+                                            "Version": "100",
                                         },
                                     }
                                 ],
@@ -72,6 +74,7 @@ class TestStatus:
                     livepatch=LivepatchPatchStatus(
                         state="nothing-to-apply",
                         fixes=None,
+                        version="100",
                     ),
                     supported=None,
                 ),
@@ -113,6 +116,7 @@ class TestStatus:
                                 patched=True,
                             )
                         ],
+                        version=None,
                     ),
                     supported=None,
                 ),
@@ -150,8 +154,7 @@ class TestStatus:
                 LivepatchStatusStatus(
                     kernel="4.15.0-187.198-generic",
                     livepatch=LivepatchPatchStatus(
-                        state="nothing-to-apply",
-                        fixes=None,
+                        state="nothing-to-apply", fixes=None, version=""
                     ),
                     supported=None,
                 ),
@@ -204,6 +207,7 @@ class TestUALivepatchClient:
             "flavor",
             "arch",
             "codename",
+            "build_date",
             "expected_request_calls",
         ],
         [
@@ -212,6 +216,9 @@ class TestUALivepatchClient:
                 "generic",
                 "amd64",
                 "xenial",
+                datetime.datetime(
+                    2020, 1, 1, 1, 1, 1, tzinfo=datetime.timezone.utc
+                ),
                 [
                     mock.call(
                         "/v1/api/kernels/supported",
@@ -221,6 +228,7 @@ class TestUALivepatchClient:
                             "flavour": "generic",
                             "architecture": "amd64",
                             "codename": "xenial",
+                            "build-date": "2020-01-01T01:01:01+00:00",
                         },
                     )
                 ],
@@ -230,6 +238,7 @@ class TestUALivepatchClient:
                 "kvm",
                 "arm64",
                 "kinetic",
+                None,
                 [
                     mock.call(
                         "/v1/api/kernels/supported",
@@ -239,6 +248,7 @@ class TestUALivepatchClient:
                             "flavour": "kvm",
                             "architecture": "arm64",
                             "codename": "kinetic",
+                            "build-date": "unknown",
                         },
                     )
                 ],
@@ -253,11 +263,14 @@ class TestUALivepatchClient:
         flavor,
         arch,
         codename,
+        build_date,
         expected_request_calls,
     ):
         m_request_url.return_value = ("mock", "mock")
         lp_client = UALivepatchClient()
-        lp_client.is_kernel_supported(version, flavor, arch, codename)
+        lp_client.is_kernel_supported(
+            version, flavor, arch, codename, build_date
+        )
         assert m_request_url.call_args_list == expected_request_calls
 
     @pytest.mark.parametrize(
@@ -266,13 +279,27 @@ class TestUALivepatchClient:
             "expected",
         ],
         [
-            ([({"Supported": True}, None)], True),
-            ([({"Supported": False}, None)], False),
-            ([({}, None)], False),
+            ([({"Supported": True}, None)], LivepatchSupport.SUPPORTED),
+            ([({"Supported": False}, None)], LivepatchSupport.UNSUPPORTED),
+            ([({}, None)], LivepatchSupport.UNSUPPORTED),
             ([([], None)], None),
             ([("string", None)], None),
             (exceptions.UrlError(mock.MagicMock()), None),
             (Exception(), None),
+            ([({"Supported": "supported"}, None)], LivepatchSupport.SUPPORTED),
+            (
+                [({"Supported": "unsupported"}, None)],
+                LivepatchSupport.UNSUPPORTED,
+            ),
+            ([({"Supported": "unknown"}, None)], LivepatchSupport.UNKNOWN),
+            (
+                [({"Supported": "kernel-end-of-life"}, None)],
+                LivepatchSupport.KERNEL_EOL,
+            ),
+            (
+                [({"Supported": "kernel-upgrade-required"}, None)],
+                LivepatchSupport.KERNEL_UPGRADE_REQUIRED,
+            ),
         ],
     )
     def test_is_kernel_supported_interprets_api_response(
@@ -284,7 +311,7 @@ class TestUALivepatchClient:
     ):
         m_request_url.side_effect = request_side_effect
         lp_client = UALivepatchClient()
-        assert lp_client.is_kernel_supported("", "", "", "") == expected
+        assert lp_client.is_kernel_supported("", "", "", "", None) == expected
 
 
 class TestOnSupportedKernel:
@@ -305,19 +332,33 @@ class TestOnSupportedKernel:
                 LivepatchStatusStatus(
                     kernel=None, livepatch=None, supported="supported"
                 ),
-                True,
+                LivepatchSupport.SUPPORTED,
             ),
             (
                 LivepatchStatusStatus(
                     kernel=None, livepatch=None, supported="unsupported"
                 ),
-                False,
+                LivepatchSupport.UNSUPPORTED,
+            ),
+            (
+                LivepatchStatusStatus(
+                    kernel=None,
+                    livepatch=None,
+                    supported="kernel-upgrade-required",
+                ),
+                LivepatchSupport.KERNEL_UPGRADE_REQUIRED,
+            ),
+            (
+                LivepatchStatusStatus(
+                    kernel=None, livepatch=None, supported="kernel-end-of-life"
+                ),
+                LivepatchSupport.KERNEL_EOL,
             ),
             (
                 LivepatchStatusStatus(
                     kernel=None, livepatch=None, supported="unknown"
                 ),
-                None,
+                LivepatchSupport.UNKNOWN,
             ),
         ],
     )
@@ -472,8 +513,8 @@ class TestOnSupportedKernel:
         ],
         [
             (
-                ("5.14-14", "generic", "amd64", "focal"),
-                True,
+                ("5.14-14", "generic", "amd64", "focal", None),
+                LivepatchSupport.SUPPORTED,
                 [
                     mock.call(
                         LivepatchSupportCacheData(
@@ -486,11 +527,11 @@ class TestOnSupportedKernel:
                         )
                     )
                 ],
-                True,
+                LivepatchSupport.SUPPORTED,
             ),
             (
-                ("5.14-14", "kvm", "arm64", "focal"),
-                False,
+                ("5.14-14", "kvm", "arm64", "focal", None),
+                LivepatchSupport.UNSUPPORTED,
                 [
                     mock.call(
                         LivepatchSupportCacheData(
@@ -503,10 +544,10 @@ class TestOnSupportedKernel:
                         )
                     )
                 ],
-                False,
+                LivepatchSupport.UNSUPPORTED,
             ),
             (
-                ("4.14-14", "kvm", "arm64", "xenial"),
+                ("4.14-14", "kvm", "arm64", "xenial", None),
                 None,
                 [
                     mock.call(
@@ -522,6 +563,23 @@ class TestOnSupportedKernel:
                 ],
                 None,
             ),
+            (
+                ("4.14-14", "kvm", "arm64", "xenial", None),
+                LivepatchSupport.UNKNOWN,
+                [
+                    mock.call(
+                        LivepatchSupportCacheData(
+                            version="4.14-14",
+                            flavor="kvm",
+                            arch="arm64",
+                            codename="xenial",
+                            supported=None,
+                            cached_at=mock.ANY,
+                        )
+                    )
+                ],
+                LivepatchSupport.UNKNOWN,
+            ),
         ],
     )
     @mock.patch(M_PATH + "state_files.livepatch_support_cache.write")
@@ -544,7 +602,7 @@ class TestOnSupportedKernel:
             "cli_result",
             "get_kernel_info_result",
             "standardize_arch_name_result",
-            "get_platform_info_result",
+            "get_release_info_result",
             "cache_result",
             "api_result",
             "cache_call_args",
@@ -552,9 +610,9 @@ class TestOnSupportedKernel:
             "expected",
         ],
         [
-            # cli result true
+            # cli result supported
             (
-                True,
+                LivepatchSupport.SUPPORTED,
                 None,
                 None,
                 None,
@@ -562,11 +620,11 @@ class TestOnSupportedKernel:
                 None,
                 [],
                 [],
-                True,
+                LivepatchSupport.SUPPORTED,
             ),
-            # cli result false
+            # cli result unsupported
             (
-                False,
+                LivepatchSupport.UNSUPPORTED,
                 None,
                 None,
                 None,
@@ -574,14 +632,52 @@ class TestOnSupportedKernel:
                 None,
                 [],
                 [],
-                False,
+                LivepatchSupport.UNSUPPORTED,
+            ),
+            # cli result upgrade-required
+            (
+                LivepatchSupport.KERNEL_UPGRADE_REQUIRED,
+                None,
+                None,
+                None,
+                None,
+                None,
+                [],
+                [],
+                LivepatchSupport.KERNEL_UPGRADE_REQUIRED,
+            ),
+            # cli result eol
+            (
+                LivepatchSupport.KERNEL_EOL,
+                None,
+                None,
+                None,
+                None,
+                None,
+                [],
+                [],
+                LivepatchSupport.KERNEL_EOL,
+            ),
+            # cli result definite unknown
+            (
+                LivepatchSupport.UNKNOWN,
+                None,
+                None,
+                None,
+                None,
+                None,
+                [],
+                [],
+                LivepatchSupport.UNKNOWN,
             ),
             # insufficient kernel info
             (
                 None,
                 system.KernelInfo(
+                    uname_machine_arch="",
                     uname_release="",
                     proc_version_signature_version="",
+                    build_date=None,
                     flavor=None,
                     major=5,
                     minor=6,
@@ -594,14 +690,16 @@ class TestOnSupportedKernel:
                 None,
                 [],
                 [],
-                None,
+                LivepatchSupport.UNKNOWN,
             ),
             # cache result true
             (
                 None,
                 system.KernelInfo(
+                    uname_machine_arch="",
                     uname_release="",
                     proc_version_signature_version="",
+                    build_date=None,
                     flavor="generic",
                     major=5,
                     minor=6,
@@ -609,19 +707,21 @@ class TestOnSupportedKernel:
                     patch=None,
                 ),
                 "amd64",
-                {"series": "xenial"},
+                mock.MagicMock(series="xenial"),
                 (True, True),
                 None,
                 [mock.call("5.6", "generic", "amd64", "xenial")],
                 [],
-                True,
+                LivepatchSupport.SUPPORTED,
             ),
             # cache result false
             (
                 None,
                 system.KernelInfo(
+                    uname_machine_arch="",
                     uname_release="",
                     proc_version_signature_version="",
+                    build_date=None,
                     flavor="generic",
                     major=5,
                     minor=6,
@@ -629,19 +729,21 @@ class TestOnSupportedKernel:
                     patch=None,
                 ),
                 "amd64",
-                {"series": "xenial"},
+                mock.MagicMock(series="xenial"),
                 (True, False),
                 None,
                 [mock.call("5.6", "generic", "amd64", "xenial")],
                 [],
-                False,
+                LivepatchSupport.UNSUPPORTED,
             ),
             # cache result none
             (
                 None,
                 system.KernelInfo(
+                    uname_machine_arch="",
                     uname_release="",
                     proc_version_signature_version="",
+                    build_date=None,
                     flavor="generic",
                     major=5,
                     minor=6,
@@ -649,19 +751,21 @@ class TestOnSupportedKernel:
                     patch=None,
                 ),
                 "amd64",
-                {"series": "xenial"},
+                mock.MagicMock(series="xenial"),
                 (True, None),
                 None,
                 [mock.call("5.6", "generic", "amd64", "xenial")],
                 [],
-                None,
+                LivepatchSupport.UNKNOWN,
             ),
             # api result true
             (
                 None,
                 system.KernelInfo(
+                    uname_machine_arch="",
                     uname_release="",
                     proc_version_signature_version="",
+                    build_date=None,
                     flavor="generic",
                     major=5,
                     minor=6,
@@ -669,35 +773,33 @@ class TestOnSupportedKernel:
                     patch=None,
                 ),
                 "amd64",
-                {"series": "xenial"},
+                mock.MagicMock(series="xenial"),
                 (False, None),
-                True,
+                LivepatchSupport.SUPPORTED,
                 [mock.call("5.6", "generic", "amd64", "xenial")],
-                [mock.call("5.6", "generic", "amd64", "xenial")],
-                True,
+                [mock.call("5.6", "generic", "amd64", "xenial", None)],
+                LivepatchSupport.SUPPORTED,
             ),
         ],
     )
     @mock.patch(M_PATH + "_on_supported_kernel_api")
     @mock.patch(M_PATH + "_on_supported_kernel_cache")
-    @mock.patch(M_PATH + "system.get_platform_info")
+    @mock.patch(M_PATH + "system.get_release_info")
     @mock.patch(M_PATH + "util.standardize_arch_name")
-    @mock.patch(M_PATH + "system.get_dpkg_arch")
     @mock.patch(M_PATH + "system.get_kernel_info")
     @mock.patch(M_PATH + "_on_supported_kernel_cli")
     def test_on_supported_kernel(
         self,
         m_supported_cli,
         m_get_kernel_info,
-        m_get_dpkg_arch,
         m_standardize_arch_name,
-        m_get_platform_info,
+        m_get_release_info,
         m_supported_cache,
         m_supported_api,
         cli_result,
         get_kernel_info_result,
         standardize_arch_name_result,
-        get_platform_info_result,
+        get_release_info_result,
         cache_result,
         api_result,
         cache_call_args,
@@ -707,7 +809,7 @@ class TestOnSupportedKernel:
         m_supported_cli.return_value = cli_result
         m_get_kernel_info.return_value = get_kernel_info_result
         m_standardize_arch_name.return_value = standardize_arch_name_result
-        m_get_platform_info.return_value = get_platform_info_result
+        m_get_release_info.return_value = get_release_info_result
         m_supported_cache.return_value = cache_result
         m_supported_api.return_value = api_result
         assert on_supported_kernel.__wrapped__() == expected
