@@ -1,5 +1,8 @@
+import datetime
 import logging
+import os
 import subprocess
+import textwrap
 import uuid
 
 import mock
@@ -10,14 +13,24 @@ from uaclient import exceptions, messages, system
 
 class TestGetKernelInfo:
     @pytest.mark.parametrize(
-        "uname_release, proc_version_signature_side_effect, expected",
+        [
+            "uname_machine",
+            "uname_release",
+            "proc_version_signature_side_effect",
+            "build_date",
+            "expected",
+        ],
         (
             (
+                "x86_64",
                 "5.14.0-1024-oem",
                 "Ubuntu 5.14.0-1024.26-oem 5.15.100",
+                datetime.datetime(2023, 4, 6, 7, 48, 48),
                 system.KernelInfo(
+                    uname_machine_arch="x86_64",
                     uname_release="5.14.0-1024-oem",
                     proc_version_signature_version="5.14.0-1024.26-oem",
+                    build_date=datetime.datetime(2023, 4, 6, 7, 48, 48),
                     major=5,
                     minor=14,
                     patch=0,
@@ -26,11 +39,32 @@ class TestGetKernelInfo:
                 ),
             ),
             (
+                "aarch64",
+                "5.14.0-1024-oem",
+                "Ubuntu 5.14.0-1024.26-oem 5.15.100",
+                datetime.datetime(2023, 4, 6, 7, 48, 48),
+                system.KernelInfo(
+                    uname_machine_arch="aarch64",
+                    uname_release="5.14.0-1024-oem",
+                    proc_version_signature_version="5.14.0-1024.26-oem",
+                    build_date=datetime.datetime(2023, 4, 6, 7, 48, 48),
+                    major=5,
+                    minor=14,
+                    patch=0,
+                    abi="1024",
+                    flavor="oem",
+                ),
+            ),
+            (
+                "x86_64",
                 "4.4.0-21-generic",
                 "Ubuntu 4.4.0-21.37-generic 4.15.100",
+                datetime.datetime(2023, 4, 6, 7, 48, 48),
                 system.KernelInfo(
+                    uname_machine_arch="x86_64",
                     uname_release="4.4.0-21-generic",
                     proc_version_signature_version="4.4.0-21.37-generic",
+                    build_date=datetime.datetime(2023, 4, 6, 7, 48, 48),
                     major=4,
                     minor=4,
                     patch=0,
@@ -39,11 +73,15 @@ class TestGetKernelInfo:
                 ),
             ),
             (
+                "x86_64",
                 "5.4.0-52-generic",
                 "Ubuntu 5.4.0-52.37-generic 5.15.100",
+                datetime.datetime(2023, 4, 6, 7, 48, 48),
                 system.KernelInfo(
+                    uname_machine_arch="x86_64",
                     uname_release="5.4.0-52-generic",
                     proc_version_signature_version="5.4.0-52.37-generic",
+                    build_date=datetime.datetime(2023, 4, 6, 7, 48, 48),
                     major=5,
                     minor=4,
                     patch=0,
@@ -52,11 +90,15 @@ class TestGetKernelInfo:
                 ),
             ),
             (
+                "x86_64",
                 "5.4.0-52-generic",
                 "Ubuntu 5.4.0-52.37~20.04-generic 5.15.100",
+                datetime.datetime(2023, 4, 6, 7, 48, 48),
                 system.KernelInfo(
+                    uname_machine_arch="x86_64",
                     uname_release="5.4.0-52-generic",
                     proc_version_signature_version="5.4.0-52.37~20.04-generic",
+                    build_date=datetime.datetime(2023, 4, 6, 7, 48, 48),
                     major=5,
                     minor=4,
                     patch=0,
@@ -65,11 +107,15 @@ class TestGetKernelInfo:
                 ),
             ),
             (
+                "x86_64",
                 "5.4.0-52-generic",
                 Exception(),
+                datetime.datetime(2023, 4, 6, 7, 48, 48),
                 system.KernelInfo(
+                    uname_machine_arch="x86_64",
                     uname_release="5.4.0-52-generic",
                     proc_version_signature_version=None,
+                    build_date=datetime.datetime(2023, 4, 6, 7, 48, 48),
                     major=5,
                     minor=4,
                     patch=0,
@@ -78,11 +124,15 @@ class TestGetKernelInfo:
                 ),
             ),
             (
+                "x86_64",
                 "5.4.0-1021-aws-fips",
                 "Ubuntu 5.4.0-1021.21+fips2-aws-fips 5.4.44",
+                datetime.datetime(2023, 4, 6, 7, 48, 48),
                 system.KernelInfo(
+                    uname_machine_arch="x86_64",
                     uname_release="5.4.0-1021-aws-fips",
                     proc_version_signature_version="5.4.0-1021.21+fips2-aws-fips",  # noqa: E501
+                    build_date=datetime.datetime(2023, 4, 6, 7, 48, 48),
                     major=5,
                     minor=4,
                     patch=0,
@@ -91,11 +141,15 @@ class TestGetKernelInfo:
                 ),
             ),
             (
+                "x86_64",
                 "4.4.0-1017-fips",
                 "Ubuntu 4.4.0-1017.22~recert1-fips 4.4.185",
+                datetime.datetime(2023, 4, 6, 7, 48, 48),
                 system.KernelInfo(
+                    uname_machine_arch="x86_64",
                     uname_release="4.4.0-1017-fips",
                     proc_version_signature_version="4.4.0-1017.22~recert1-fips",  # noqa: E501
+                    build_date=datetime.datetime(2023, 4, 6, 7, 48, 48),
                     major=4,
                     minor=4,
                     patch=0,
@@ -104,11 +158,32 @@ class TestGetKernelInfo:
                 ),
             ),
             (
+                "x86_64",
                 "4.4.0-1017.something.invalid-fips",
                 "Ubuntu 4.4.0-1017.22~recert1-fips 4.4.185",
+                datetime.datetime(2023, 4, 6, 7, 48, 48),
                 system.KernelInfo(
+                    uname_machine_arch="x86_64",
                     uname_release="4.4.0-1017.something.invalid-fips",
                     proc_version_signature_version="4.4.0-1017.22~recert1-fips",  # noqa: E501
+                    build_date=datetime.datetime(2023, 4, 6, 7, 48, 48),
+                    major=None,
+                    minor=None,
+                    patch=None,
+                    abi=None,
+                    flavor=None,
+                ),
+            ),
+            (
+                "x86_64",
+                "4.4.0-1017.something.invalid-fips",
+                "Ubuntu 4.4.0-1017.22~recert1-fips 4.4.185",
+                None,
+                system.KernelInfo(
+                    uname_machine_arch="x86_64",
+                    uname_release="4.4.0-1017.something.invalid-fips",
+                    proc_version_signature_version="4.4.0-1017.22~recert1-fips",  # noqa: E501
+                    build_date=None,
                     major=None,
                     minor=None,
                     patch=None,
@@ -118,20 +193,139 @@ class TestGetKernelInfo:
             ),
         ),
     )
+    @mock.patch("uaclient.system._get_kernel_build_date")
     @mock.patch("uaclient.system.load_file")
     @mock.patch("uaclient.system.os.uname")
     def test_get_kernel_info(
         self,
         m_uname,
         m_load_file,
+        m_get_kernel_build_date,
+        uname_machine,
         uname_release,
         proc_version_signature_side_effect,
+        build_date,
         expected,
     ):
-        m_uname.return_value = mock.MagicMock(release=uname_release)
+        m_uname.return_value = mock.MagicMock(
+            release=uname_release, machine=uname_machine
+        )
         m_load_file.side_effect = [proc_version_signature_side_effect]
+        m_get_kernel_build_date.return_value = build_date
         assert system.get_kernel_info.__wrapped__() == expected
 
+    @pytest.mark.parametrize(
+        [
+            "uname_result",
+            "changelog_timestamp",
+            "expected",
+        ],
+        [
+            (
+                os.uname_result(
+                    [
+                        "",
+                        "",
+                        "",
+                        "#20-Ubuntu SMP PREEMPT_DYNAMIC Thu Apr  6 07:48:48 UTC 2023",  # noqa: E501
+                        "",
+                    ]
+                ),
+                mock.sentinel.changelog_timestamp,
+                datetime.datetime(
+                    2023, 4, 6, 7, 48, 48, tzinfo=datetime.timezone.utc
+                ),
+            ),
+            (
+                os.uname_result(
+                    [
+                        "",
+                        "",
+                        "",
+                        "#33~22.04.1-Ubuntu SMP PREEMPT_DYNAMIC Mon Jan 30 17:03:34 UTC 2",  # noqa: E501
+                        "",
+                    ]
+                ),
+                mock.sentinel.changelog_timestamp,
+                mock.sentinel.changelog_timestamp,
+            ),
+            (
+                os.uname_result(["", "", "", "corrupted", ""]),
+                mock.sentinel.changelog_timestamp,
+                mock.sentinel.changelog_timestamp,
+            ),
+        ],
+    )
+    @mock.patch("uaclient.system._get_kernel_changelog_timestamp")
+    def test_get_kernel_build_date(
+        self,
+        m_get_kernel_changelog_timestamp,
+        uname_result,
+        changelog_timestamp,
+        expected,
+    ):
+        m_get_kernel_changelog_timestamp.return_value = changelog_timestamp
+        assert expected == system._get_kernel_build_date(uname_result)
+
+    @pytest.mark.parametrize(
+        [
+            "uname_result",
+            "is_container",
+            "stat_result",
+            "expected_stat_call_args",
+            "expected",
+        ],
+        [
+            (
+                None,
+                True,
+                None,
+                [],
+                None,
+            ),
+            (
+                os.uname_result(["", "", "version-here", "", ""]),
+                False,
+                Exception(),
+                [
+                    mock.call(
+                        "/usr/share/doc/linux-image-version-here/changelog.Debian.gz"  # noqa: E501
+                    )
+                ],
+                None,
+            ),
+            (
+                os.uname_result(["", "", "version-here", "", ""]),
+                False,
+                [os.stat_result([0, 0, 0, 0, 0, 0, 0, 0, 1680762951, 0])],
+                [
+                    mock.call(
+                        "/usr/share/doc/linux-image-version-here/changelog.Debian.gz"  # noqa: E501
+                    )
+                ],
+                datetime.datetime(
+                    2023, 4, 6, 6, 35, 51, tzinfo=datetime.timezone.utc
+                ),
+            ),
+        ],
+    )
+    @mock.patch("os.stat")
+    @mock.patch("uaclient.system.is_container")
+    def test_get_kernel_changelog_timestamp(
+        self,
+        m_is_container,
+        m_os_stat,
+        uname_result,
+        is_container,
+        stat_result,
+        expected_stat_call_args,
+        expected,
+    ):
+        m_is_container.return_value = is_container
+        m_os_stat.side_effect = stat_result
+        assert expected == system._get_kernel_changelog_timestamp(uname_result)
+        assert expected_stat_call_args == m_os_stat.call_args_list
+
 
 class TestGetDpkgArch:
     @pytest.mark.parametrize(
@@ -457,9 +651,9 @@ LOGO=ubuntu-logo
     )
     @mock.patch("uaclient.system.load_file")
     def test_parse_os_release(self, m_load_file, content, expected):
-        """parse_os_release returns a dict of values from /etc/os-release."""
+        """_parse_os_release returns a dict of values from /etc/os-release."""
         m_load_file.return_value = content
-        assert expected == system.parse_os_release.__wrapped__()
+        assert expected == system._parse_os_release.__wrapped__()
         assert m_load_file.call_args_list == [mock.call("/etc/os-release")]
 
 
@@ -508,9 +702,9 @@ version,codename,series,created,release,eol,eol-server,eol-esm
         assert messages.MISSING_DISTRO_INFO_FILE == excinfo.value.msg
 
 
-class TestGetPlatformInfo:
+class TestGetReleaseInfo:
     @pytest.mark.parametrize(
-        "version, expected_exception",
+        ["version", "expected_exception"],
         (
             (
                 "junk",
@@ -522,95 +716,67 @@ class TestGetPlatformInfo:
             ),
         ),
     )
-    @mock.patch("uaclient.system.parse_os_release")
-    def test_get_platform_info_error(
-        self, m_parse, version, expected_exception
+    @mock.patch("uaclient.system._parse_os_release")
+    def test_get_release_info_error(
+        self, m_parse_os_release, version, expected_exception
     ):
-        """get_platform_info errors when it cannot parse os-release."""
-        m_parse.return_value = {"VERSION": version}
+        """get_release_info errors when it cannot parse os-release."""
+        m_parse_os_release.return_value = {"VERSION": version}
         with pytest.raises(expected_exception):
             # Use __wrapped__ to avoid hitting the
             # lru_cached value across tests
-            system.get_platform_info.__wrapped__()
+            system.get_release_info.__wrapped__()
 
     @pytest.mark.parametrize(
-        "os_release,arch,kernel,virt,expected",
+        ["os_release", "expected"],
         [
             (
                 {
                     "NAME": "Ubuntu",
                     "VERSION": "16.04.5 LTS (Xenial Xerus)",
                 },
-                "arm64",
-                "kernel-ver1",
-                "lxd",
-                {
-                    "arch": "arm64",
-                    "distribution": "Ubuntu",
-                    "kernel": "kernel-ver1",
-                    "release": "16.04",
-                    "series": "xenial",
-                    "type": "Linux",
-                    "version": "16.04 LTS (Xenial Xerus)",
-                    "virt": "lxd",
-                },
+                system.ReleaseInfo(
+                    distribution="Ubuntu",
+                    release="16.04",
+                    series="xenial",
+                    pretty_version="16.04 LTS (Xenial Xerus)",
+                ),
             ),
             (
                 {
                     "NAME": "Ubuntu",
                     "VERSION": "18.04.1 LTS (Bionic Beaver)",
                 },
-                "amd64",
-                "kernel-ver2",
-                "none",
-                {
-                    "arch": "amd64",
-                    "distribution": "Ubuntu",
-                    "kernel": "kernel-ver2",
-                    "release": "18.04",
-                    "series": "bionic",
-                    "type": "Linux",
-                    "version": "18.04 LTS (Bionic Beaver)",
-                    "virt": "none",
-                },
+                system.ReleaseInfo(
+                    distribution="Ubuntu",
+                    release="18.04",
+                    series="bionic",
+                    pretty_version="18.04 LTS (Bionic Beaver)",
+                ),
             ),
             (
                 {
                     "NAME": "Ubuntu",
                     "VERSION": "22.04.1 LTS (Jammy Jellyfish)",
                 },
-                "arm64",
-                "kernel-ver3",
-                "qemu",
-                {
-                    "arch": "arm64",
-                    "distribution": "Ubuntu",
-                    "kernel": "kernel-ver3",
-                    "release": "22.04",
-                    "series": "jammy",
-                    "type": "Linux",
-                    "version": "22.04 LTS (Jammy Jellyfish)",
-                    "virt": "qemu",
-                },
+                system.ReleaseInfo(
+                    distribution="Ubuntu",
+                    release="22.04",
+                    series="jammy",
+                    pretty_version="22.04 LTS (Jammy Jellyfish)",
+                ),
             ),
             (
                 {
                     "NAME": "Ubuntu",
-                    "VERSION": "22.10 LTS (Kinetic Kudu)",
-                },
-                "amd64",
-                "kernel-ver4",
-                "wsl",
-                {
-                    "arch": "amd64",
-                    "distribution": "Ubuntu",
-                    "kernel": "kernel-ver4",
-                    "release": "22.10",
-                    "series": "kinetic",
-                    "type": "Linux",
-                    "version": "22.10 LTS (Kinetic Kudu)",
-                    "virt": "wsl",
+                    "VERSION": "22.10 (Kinetic Kudu)",
                 },
+                system.ReleaseInfo(
+                    distribution="Ubuntu",
+                    release="22.10",
+                    series="kinetic",
+                    pretty_version="22.10 (Kinetic Kudu)",
+                ),
             ),
             (
                 {
@@ -618,19 +784,12 @@ class TestGetPlatformInfo:
                     "VERSION": "22.04 LTS",
                     "VERSION_CODENAME": "Jammy",
                 },
-                "amd64",
-                "kernel-ver4",
-                "lxd",
-                {
-                    "arch": "amd64",
-                    "distribution": "Ubuntu",
-                    "kernel": "kernel-ver4",
-                    "release": "22.04",
-                    "series": "jammy",
-                    "type": "Linux",
-                    "version": "22.04 LTS",
-                    "virt": "lxd",
-                },
+                system.ReleaseInfo(
+                    distribution="Ubuntu",
+                    release="22.04",
+                    series="jammy",
+                    pretty_version="22.04 LTS",
+                ),
             ),
             (
                 {
@@ -639,43 +798,30 @@ class TestGetPlatformInfo:
                     "VERSION_CODENAME": "Jammy",
                     "VERSION_ID": "22.04",
                 },
-                "amd64",
-                "kernel-ver4",
-                "lxd",
-                {
-                    "arch": "amd64",
-                    "distribution": "Ubuntu",
-                    "kernel": "kernel-ver4",
-                    "release": "22.04",
-                    "series": "jammy",
-                    "type": "Linux",
-                    "version": "CORRUPTED",
-                    "virt": "lxd",
-                },
+                system.ReleaseInfo(
+                    distribution="Ubuntu",
+                    release="22.04",
+                    series="jammy",
+                    pretty_version="CORRUPTED",
+                ),
             ),
         ],
     )
     @mock.patch("uaclient.system.get_kernel_info")
     @mock.patch("uaclient.system.get_dpkg_arch")
-    @mock.patch("uaclient.system.parse_os_release")
+    @mock.patch("uaclient.system._parse_os_release")
     @mock.patch("uaclient.system.get_virt_type")
-    def test_get_platform_info_with_version(
+    def test_get_release_info_with_version(
         self,
         m_get_virt_type,
         m_parse_os_release,
         m_get_dpkg_arch,
         m_get_kernel_info,
         os_release,
-        arch,
-        kernel,
-        virt,
         expected,
     ):
         m_parse_os_release.return_value = os_release
-        m_get_dpkg_arch.return_value = arch
-        m_get_kernel_info.return_value = mock.MagicMock(uname_release=kernel)
-        m_get_virt_type.return_value = virt
-        assert expected == system.get_platform_info.__wrapped__()
+        assert expected == system.get_release_info.__wrapped__()
 
 
 class TestGetMachineId:
@@ -956,6 +1102,49 @@ class TestSubp:
             else:
                 assert log not in logs
 
+    @pytest.mark.parametrize(
+        [
+            "override_env_vars",
+            "os_environ",
+            "expected_env_arg",
+        ],
+        (
+            (None, {}, None),
+            (None, {"test": "val"}, None),
+            ({}, {"test": "val"}, None),
+            ({"set": "new"}, {"test": "val"}, {"test": "val", "set": "new"}),
+            (
+                {"set": "new", "test": "newval"},
+                {"test": "val"},
+                {"test": "newval", "set": "new"},
+            ),
+        ),
+    )
+    @mock.patch("subprocess.Popen")
+    def test_subp_uses_environment_variables(
+        self,
+        m_popen,
+        override_env_vars,
+        os_environ,
+        expected_env_arg,
+        _subp,
+    ):
+        mock_process = mock.MagicMock(returncode=0)
+        mock_process.communicate.return_value = (b"", b"")
+        m_popen.return_value = mock_process
+
+        with mock.patch("os.environ", os_environ):
+            _subp(["apt", "nothing"], override_env_vars=override_env_vars)
+
+        assert [
+            mock.call(
+                [b"apt", b"nothing"],
+                stdout=subprocess.PIPE,
+                stderr=subprocess.PIPE,
+                env=expected_env_arg,
+            )
+        ] == m_popen.call_args_list
+
 
 class TestGetSystemdJobState:
     @pytest.mark.parametrize(
@@ -987,3 +1176,109 @@ class TestGetSystemdJobState:
             cmd="test", exit_code=3, stdout="inactive", stderr=""
         )
         assert False is system.get_systemd_job_state(job_name="test")
+
+
+class TestGetCpuInfo:
+    @pytest.mark.parametrize(
+        "cpuinfo,vendor_id,model,stepping",
+        (
+            (
+                textwrap.dedent(
+                    """
+                processor       : 6
+                vendor_id       : GenuineIntel
+                cpu family      : 6
+                model           : 142
+                model name      : Intel(R) Core(TM) i7-8650U CPU @ 1.90GHz
+                stepping        : 10
+
+                processor       : 7
+                vendor_id       : GenuineIntel
+                cpu family      : 6
+                model           : 142
+                model name      : Intel(R) Core(TM) i7-8650U CPU @ 1.90GHz
+                stepping        : 10"""
+                ),
+                "intel",
+                142,
+                10,
+            ),
+            (
+                textwrap.dedent(
+                    """
+                processor       : 6
+                vendor_id       : test
+                cpu family      : 6
+                model           : 148
+                model name      : Intel(R) Core(TM) i7-8650U CPU @ 1.90GHz
+                stepping        : 12
+
+                processor       : 7
+                vendor_id       : GenuineIntel
+                cpu family      : 6
+                model           : 142
+                model name      : Intel(R) Core(TM) i7-8650U CPU @ 1.90GHz
+                stepping        : 10"""
+                ),
+                "test",
+                148,
+                12,
+            ),
+            (
+                textwrap.dedent(
+                    """
+                processor       : 6
+                cpu family      : 6
+                model name      : Intel(R) Core(TM) i7-8650U CPU @ 1.90GHz
+
+                processor       : 7
+                cpu family      : 6
+                model name      : Intel(R) Core(TM) i7-8650U CPU @ 1.90GHz"""
+                ),
+                "",
+                None,
+                None,
+            ),
+        ),
+    )
+    @mock.patch("uaclient.system.load_file")
+    def test_get_cpu_vendor(
+        self, m_load_file, cpuinfo, vendor_id, model, stepping
+    ):
+        m_load_file.return_value = cpuinfo
+        assert vendor_id == system.get_cpu_info.__wrapped__().vendor_id
+        assert model == system.get_cpu_info.__wrapped__().model
+        assert stepping == system.get_cpu_info.__wrapped__().stepping
+
+
+class TestGetUserCacheDir:
+    @pytest.mark.parametrize(
+        [
+            "is_root",
+            "xdg_cache_home",
+            "expanduser_result",
+            "expected",
+        ],
+        (
+            (True, None, None, "/run/ubuntu-advantage/"),
+            (False, None, "/home/user", "/home/user/.cache/ubuntu-pro"),
+            (False, "/something", "/home/user", "/something/ubuntu-pro"),
+        ),
+    )
+    @mock.patch("os.path.expanduser")
+    @mock.patch("os.environ.get")
+    @mock.patch("uaclient.util.we_are_currently_root")
+    def test_get_user_cache_dir(
+        self,
+        m_we_are_currently_root,
+        m_environ_get,
+        m_expanduser,
+        is_root,
+        xdg_cache_home,
+        expanduser_result,
+        expected,
+    ):
+        m_we_are_currently_root.return_value = is_root
+        m_environ_get.return_value = xdg_cache_home
+        m_expanduser.return_value = expanduser_result
+        assert expected == system.get_user_cache_dir()
