@@ -9,6 +9,7 @@ import mock
 import pytest
 
 from uaclient import cli, exceptions, messages, util
+from uaclient.log import RedactionFilter
 
 
 class TestGetDictDeltas:
@@ -71,7 +72,9 @@ class TestIsServiceUrl:
 
 
 class TestReadurl:
-    @pytest.mark.parametrize("caplog_text", [logging.DEBUG], indirect=True)
+    @pytest.mark.parametrize(
+        "caplog_text", [(logging.DEBUG, RedactionFilter)], indirect=True
+    )
     @pytest.mark.parametrize(
         "headers,data,method,url,response,expected_logs",
         (
@@ -200,13 +203,22 @@ class TestDisableLogToConsole:
         assert "no console handler found" in caplog_text()
 
     @pytest.mark.parametrize("disable_log", (True, False))
+    @mock.patch("uaclient.log.get_user_log_file")
     def test_disable_log_to_console(
-        self, m_we_are_currently_root, logging_sandbox, capsys, disable_log
+        self,
+        m_get_user,
+        m_we_are_currently_root,
+        logging_sandbox,
+        capsys,
+        tmpdir,
+        disable_log,
     ):
         # This test is parameterised so that we are sure that the context
         # manager is suppressing the output, not some other config change
 
-        cli.setup_logging(logging.INFO, logging.INFO)
+        log_file = tmpdir.join("file.log").strpath
+        m_get_user.return_value = log_file
+        cli.setup_logging(logging.INFO, logging.INFO, log_file=log_file)
 
         if disable_log:
             context_manager = util.disable_log_to_console
@@ -225,14 +237,25 @@ class TestDisableLogToConsole:
             assert "test error" in combined_output
             assert "test info" in combined_output
 
+    @mock.patch("uaclient.log.get_user_log_file")
     def test_disable_log_to_console_does_nothing_at_debug_level(
-        self, m_we_are_currently_root, logging_sandbox, capsys
+        self,
+        m_get_user,
+        m_we_are_currently_root,
+        logging_sandbox,
+        capsys,
+        FakeConfig,
+        tmpdir,
     ):
-        cli.setup_logging(logging.DEBUG, logging.DEBUG)
+        m_get_user.return_value = tmpdir.join("file.log").strpath
+        with mock.patch(
+            "uaclient.cli.config.UAConfig", return_value=FakeConfig()
+        ):
+            cli.setup_logging(logging.DEBUG, logging.DEBUG)
 
-        with util.disable_log_to_console():
-            logging.error("test error")
-            logging.info("test info")
+            with util.disable_log_to_console():
+                logging.error("test error")
+                logging.info("test info")
 
         out, err = capsys.readouterr()
         combined_output = out + err
@@ -264,7 +287,6 @@ class TestDatetimeAwareJSONEncoder:
 
 
 class TestDatetimeAwareJSONDecoder:
-
     # Note that the parameter names are flipped from
     # TestDatetimeAwareJSONEncoder
     @pytest.mark.parametrize("out,input", JSON_TEST_PAIRS)
@@ -668,6 +690,7 @@ class TestHandleUnicodeCharacters:
             (messages.OKGREEN_CHECK + " test", "test"),
             (messages.FAIL_X + " fail", "fail"),
             ("\u2014 blah", "- blah"),
+            ("\xfcblah", "blah"),
         ),
     )
     def test_handle_unicode_characters(
